<?php
// admin/admin-main.php
if (!defined('ABSPATH')) {
    exit; // 禁止直接访问
}

// 权限验证（仅管理员可访问）
if (!current_user_can('manage_options')) {
    wp_die(__('抱歉，您没有权限访问此页面'));
}

global $wpdb, $title;
$title = 'VIP双卡系统管理后台'; // 设置页面标题

// 加载WordPress后台头部
require_once(ABSPATH . 'wp-admin/admin-header.php');

// 数据库表名
$table_name = $wpdb->prefix . 'cao_cdk_tbl';

// 获取卡密统计数据（真实数据）
$recharge_stats = [
    'total' => $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE type = 1"),
    'claimed' => $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE type = 1 AND Camilla = 1"),
    'used' => $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE type = 1 AND status = 1"),
    'available' => $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE type = 1 AND Camilla = 0")
];

$vip_stats = [
    'total' => $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE type = 2"),
    'claimed' => $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE type = 2 AND Camilla = 1"),
    'used' => $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE type = 2 AND status = 1"),
    'available' => $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE type = 2 AND Camilla = 0")
];

// 最近领取记录（真实数据）- 只显示有用户信息的记录
$recent_records = $wpdb->get_results(
    "SELECT * FROM $table_name 
     WHERE Camilla = 1 
       AND user IS NOT NULL 
       AND user != '' 
     ORDER BY create_time DESC 
     LIMIT 5",
    ARRAY_A
);

// 获取前台显示设置
$frontend_name = get_option('vip_card_system_frontend_name', 'VIP尊享卡领取中心');
$welcome_message = get_option('vip_card_system_welcome_message', '尊贵用户专享特权，领取您的专属VIP卡或充值卡');
$usage_instructions = get_option('vip_card_system_usage_instructions', ''); // 使用说明设置
$page_scale = get_option('vip_card_system_page_scale', 100); // 页面缩放比例设置

// 获取系统设置
$countdown_mode = get_option('vip_card_system_countdown_mode', 'hour'); // 倒计时模式
$countdown_time = get_option('vip_card_system_countdown_time', 24); // 倒计时时长（小时）
$countdown_end_date = get_option('vip_card_system_countdown_end_date', date('Y-m-d', strtotime('+1 day'))); // 结束日期
$countdown_end_time = get_option('vip_card_system_countdown_end_time', '23:59'); // 结束时间
$ip_restriction = get_option('vip_card_system_ip_restriction', 1);
$time_restriction = get_option('vip_card_system_time_restriction', 1);
$email_notification = get_option('vip_card_system_email_notification', 1);
$low_stock_notification = get_option('vip_card_system_low_stock_notification', 0);
$admin_email = get_option('vip_card_system_notification_email', get_option('admin_email'));
$theme = get_option('vip_card_system_theme', 'red');

// 卡片背景色设置
$recharge_card_bg = get_option('vip_card_system_recharge_card_bg', '');
$vip_card_bg = get_option('vip_card_system_vip_card_bg', '');

// 获取用户角色设置
$allowed_roles = get_option('vip_card_system_user_roles', ['subscriber', 'contributor', 'author', 'editor', 'administrator']);

// 定义所有可能的用户角色
$all_roles = [
    'subscriber' => '订阅者',
    'contributor' => '投稿者',
    'author' => '作者',
    'editor' => '编辑',
    'administrator' => '管理员'
];
?>

<div class="vip-card-admin">
    <!-- 标签导航 -->
    <div class="admin-tabs">
        <div class="admin-tab active" data-tab="dashboard">系统概览</div>
        <div class="admin-tab" data-tab="settings">系统设置</div>
        <div class="admin-tab" data-tab="reports">统计报表</div>
    </div>
    
    <!-- 系统概览 -->
    <div class="tab-content active" id="dashboard">
        <!-- 新增的短代码提示框 -->
    <div class="vip-card-shortcode-notice">
        <div class="notice-content">
            <h3><span class="dashicons dashicons-info"></span> 前台显示设置</h3>
            <p>要显示活动页面，请将以下短代码添加到您的页面或小工具中：</p>
            <div class="shortcode-box">
                <code id="shortcode-text">[vip_card_system]</code>
                <button id="copy-shortcode" class="btn small">
                    <span class="dashicons dashicons-clipboard"></span> 复制短代码
                </button>
            </div>
            <p class="usage-instructions">
                添加位置：
                <span class="dashicons dashicons-edit"></span> 页面编辑器 | 
                <span class="dashicons dashicons-welcome-widgets-menus"></span> 小工具区域 | 
                <span class="dashicons dashicons-shortcode"></span> 自定义HTML
            </p>
        </div>
        <div class="notice-actions">
            <a href="<?php echo admin_url('post-new.php?post_type=page'); ?>" class="btn" target="_blank">
                <span class="dashicons dashicons-plus"></span> 创建新页面
            </a>
            <a href="<?php echo admin_url('widgets.php'); ?>" class="btn" target="_blank">
                <span class="dashicons dashicons-admin-appearance"></span> 管理小工具
            </a>
        </div>
    </div>
        
        
       <!-- 活动管理 -->
        <div class="form-section">
            <h3><span class="dashicons dashicons-update"></span> 活动管理</h3>
            
            <div class="settings-grid">
                <div class="setting-card">
                    <h4>开启新一轮活动</h4>
                    <p>重置所有用户的领取信息，让用户可以重新领取卡密</p>
                    
                    <div class="form-group">
                        <button class="btn" id="new-activity-btn">
                            <span class="dashicons dashicons-update"></span> 开启新一轮活动
                        </button>
                        <p class="help-text">此操作不可撤销！</p>
                    </div>
                    
                    <div id="reset-result" style="display: none; margin-top: 15px; padding: 10px; border-radius: 5px; background: #f0f0f1;"></div>
                </div>
            </div>
        </div>
        <!-- 数据统计卡片 -->
        <div class="stats-container">
            <!-- 充值卡统计 -->
            <div class="stat-card recharge">
                <h3><span class="dashicons dashicons-money-alt"></span> 余额充值卡</h3>
                <div class="stat-value"><?php echo $recharge_stats['available']; ?>/<?php echo $recharge_stats['total']; ?></div>
                <div class="stat-label">剩余可领取数量</div>
                
                <div class="progress-container">
                    <?php 
                    $width = $recharge_stats['total'] > 0 
                        ? (($recharge_stats['total'] - $recharge_stats['available']) / $recharge_stats['total'] * 100) 
                        : 0;
                    ?>
                    <div class="progress-bar" style="width: <?php echo $width; ?>%"></div>
                </div>
                
                <div class="stat-details">
                    <div class="stat-detail">总卡数 <span><?php echo $recharge_stats['total']; ?></span></div>
                    <div class="stat-detail">已领取 <span><?php echo $recharge_stats['claimed']; ?></span></div>
                    <div class="stat-detail">已使用 <span><?php echo $recharge_stats['used']; ?></span></div>
                </div>
            </div>
            
            <!-- VIP卡统计 -->
            <div class="stat-card vip">
                <h3><span class="dashicons dashicons-awards"></span> 会员特权卡</h3>
                <div class="stat-value"><?php echo $vip_stats['available']; ?>/<?php echo $vip_stats['total']; ?></div>
                <div class="stat-label">剩余可领取数量</div>
                
                <div class="progress-container">
                    <?php 
                    $width = $vip_stats['total'] > 0 
                        ? (($vip_stats['total'] - $vip_stats['available']) / $vip_stats['total'] * 100) 
                        : 0;
                    ?>
                    <div class="progress-bar" style="width: <?php echo $width; ?>%"></div>
                </div>
                
                <div class="stat-details">
                    <div class="stat-detail">总卡数 <span><?php echo $vip_stats['total']; ?></span></div>
                    <div class="stat-detail">已领取 <span><?php echo $vip_stats['claimed']; ?></span></div>
                    <div class="stat-detail">已使用 <span><?php echo $vip_stats['used']; ?></span></div>
                </div>
            </div>
        </div>
        
        <!-- 最近记录 -->
        <div class="form-section">
            <h3><span class="dashicons dashicons-clock"></span> 最近领取记录</h3>
            <div class="card-list">
                <div class="card-list-body">
                    <?php if (!empty($recent_records)): ?>
    <?php foreach ($recent_records as $record): 
        // 从user字段解析用户信息
        $user_info = json_decode($record['user'], true);
    ?>
    <div class="card-item">
        <div class="card-type-badge <?php echo $record['type'] == 1 ? 'recharge-badge' : 'vip-badge'; ?>">
            <?php echo $record['type'] == 1 ? '充值卡' : '会员卡'; ?>
        </div>
        <div class="card-code"><?php echo esc_html($record['code']); ?></div>
        <div class="card-status status-<?php echo $record['status']; ?>">
            <?php 
                if($record['status'] == 0) echo '未使用';
                if($record['status'] == 1) echo '已使用';
            ?>
        </div>
        <div class="card-user">用户：<strong><?php echo isset($user_info['user_name']) ? esc_html($user_info['user_name']) : '未知用户'; ?></strong></div>
    </div>
    <?php endforeach; ?>
<?php else: ?>
                        <div class="no-records">
                            <span class="dashicons dashicons-info"></span>
                            <p>暂无领取记录</p>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
    
    <!-- 系统设置 -->
    <div class="tab-content" id="settings">
        <!-- 主题设置 -->
<div class="form-section">
    <h3><span class="dashicons dashicons-admin-appearance"></span> 主题设置</h3>
    
    <div class="theme-options">
        <?php 
        $themes = [
            'red' => ['name' => '红色主题', 'preview' => '红色尊贵主题'],
            'blue' => ['name' => '蓝色主题', 'preview' => '蓝色商务主题'],
            'purple' => ['name' => '紫色主题', 'preview' => '紫色优雅主题'],
            'green' => ['name' => '绿色主题', 'preview' => '绿色清新主题'],
            'gold' => ['name' => '金色主题', 'preview' => '金色奢华主题']
        ];
        ?>
        <?php foreach ($themes as $key => $theme): ?>
            <div class="theme-option theme-<?php echo $key; ?> <?php echo $key === $theme ? 'active' : ''; ?>" 
                 data-theme="<?php echo $key; ?>">
                <div class="theme-preview"><?php echo $theme['preview']; ?></div>
                <div class="theme-name"><?php echo $theme['name']; ?></div>
            </div>
        <?php endforeach; ?>
    </div>
    
    <!-- 添加主题选择状态显示 -->
    <div class="theme-selection-status" style="margin-top: 15px; display: none;">
        <span class="dashicons dashicons-yes"></span>
        <span>主题已选择: <strong id="selected-theme-name"><?php echo $themes[$theme]['name']; ?></strong></span>
    </div>
</div>
        
        <!-- 卡片背景色设置 -->
        <div class="form-section">
            <h3><span class="dashicons dashicons-art"></span> 卡片背景色设置</h3>
            
            <div class="settings-grid">
                <!-- 充值卡背景色设置 -->
                <div class="setting-card">
                    <h4><span class="dashicons dashicons-money-alt"></span> 充值卡背景色</h4>
                    <div class="form-group">
                        <label for="recharge-card-bg">选择背景色</label>
                        <input type="text" id="recharge-card-bg" class="form-control color-field" 
                               value="<?php echo esc_attr($recharge_card_bg); ?>">
                        <p class="help-text">设置充值卡背景颜色</p>
                    </div>
                </div>
                
                <!-- VIP卡背景色设置 -->
                <div class="setting-card">
                    <h4><span class="dashicons dashicons-awards"></span> VIP卡背景色</h4>
                    <div class="form-group">
                        <label for="vip-card-bg">选择背景色</label>
                        <input type="text" id="vip-card-bg" class="form-control color-field" 
                               value="<?php echo esc_attr($vip_card_bg); ?>">
                        <p class="help-text">设置VIP卡背景颜色</p>
                    </div>
                </div>
            </div>
        </div>
        
        <!-- 系统参数设置 -->
        <div class="form-section">
            <h3><span class="dashicons dashicons-admin-generic"></span> 系统参数设置</h3>
            <div class="settings-grid">
                <div class="setting-card">
                    <h4><span class="dashicons dashicons-clock"></span> 倒计时设置</h4>
                    
                    <!-- 倒计时模式选择 -->
                    <div class="vip-card-setting-row">
                        <label>倒计时模式</label>
                        <div class="setting-field">
                            <label class="radio-inline">
                                <input type="radio" name="countdownMode" value="hour" <?php checked($countdown_mode, 'hour'); ?>>
                                小时倒计时
                            </label>
                            <label class="radio-inline">
                                <input type="radio" name="countdownMode" value="date" <?php checked($countdown_mode, 'date'); ?>>
                                指定日期
                            </label>
                        </div>
                    </div>

                    <!-- 小时模式设置 -->
                    <div id="hour-mode-settings" class="vip-card-setting-row" style="<?php echo ($countdown_mode === 'date') ? 'display:none;' : ''; ?>">
                        <label>倒计时时长(小时)</label>
                        <div class="setting-field">
                            <input type="number" name="countdownTime" value="<?php echo esc_attr($countdown_time); ?>" min="1" max="720">
                            <p class="description">设置活动开始后的倒计时时长（小时）</p>
                        </div>
                    </div>

                    <!-- 日期模式设置 -->
                    <div id="date-mode-settings" class="vip-card-setting-row" style="<?php echo ($countdown_mode === 'hour') ? 'display:none;' : ''; ?>">
                        <label>结束日期</label>
                        <div class="setting-field">
                            <input type="date" name="countdownEndDate" value="<?php echo esc_attr($countdown_end_date); ?>">
                            <input type="time" name="countdownEndTime" value="<?php echo esc_attr($countdown_end_time); ?>">
                            <p class="description">设置活动的具体结束日期和时间</p>
                        </div>
                    </div>
                </div>
                
                <!-- 安全设置 -->
                <div class="setting-card">
                    <h4><span class="dashicons dashicons-shield"></span> 安全设置</h4>
                    <div class="form-group">
                        <label>
                            <input type="checkbox" id="ip-restriction" <?php checked($ip_restriction, 1); ?>> 
                            启用IP限制
                        </label>
                        <p class="help-text">同一IP地址限制领取次数</p>
                    </div>
                    
                    <div class="form-group">
                        <label>
                            <input type="checkbox" id="time-restriction" <?php checked($time_restriction, 1); ?>> 
                            启用时间间隔限制
                        </label>
                        <p class="help-text">30天内仅可领取一次同类型卡</p>
                    </div>
                </div>
                
                <!-- 权限设置 -->
                <div class="setting-card">
                    <h4><span class="dashicons dashicons-admin-users"></span> 权限设置</h4>
                    <div class="form-group">
                        <label for="userRoles">允许领取的用户角色</label>
                        <select id="userRoles" class="form-control" multiple style="height: 120px;">
                            <?php foreach ($all_roles as $role_key => $role_name): ?>
                                <option value="<?php echo esc_attr($role_key); ?>" 
                                    <?php echo in_array($role_key, $allowed_roles) ? 'selected' : ''; ?>>
                                    <?php echo esc_html($role_name); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                </div>
                
                <!-- 通知设置 -->
                <div class="setting-card">
                    <h4><span class="dashicons dashicons-email-alt"></span> 通知设置</h4>
                    <div class="form-group">
                        <label>
                            <input type="checkbox" id="email-notification" <?php checked($email_notification, 1); ?>> 
                            卡密领取时发送邮件通知
                        </label>
                    </div>
                    
                    <div class="form-group">
                        <label>
                            <input type="checkbox" id="low-stock-notification" <?php checked($low_stock_notification, 1); ?>> 
                            卡密库存不足时发送通知
                        </label>
                    </div>
                    
                    <div class="form-group">
                        <label for="adminEmail">管理员邮箱</label>
                        <input type="email" id="adminEmail" class="form-control" 
                               value="<?php echo esc_attr($admin_email); ?>">
                    </div>
                </div>
                
                <!-- 前台显示设置 -->
                <div class="setting-card">
                    <h4><span class="dashicons dashicons-visibility"></span> 前台显示设置</h4>
                    <div class="form-group">
                        <label for="frontendName">系统名称</label>
                        <input type="text" id="frontendName" class="form-control" 
                               value="<?php echo esc_attr($frontend_name); ?>">
                        <p class="help-text">显示在前台页面顶部的系统名称</p>
                    </div>
                    
                    <div class="form-group">
                        <label for="welcomeMessage">欢迎消息</label>
                        <textarea id="welcomeMessage" class="form-control" rows="2"><?php 
                            echo esc_textarea($welcome_message); 
                        ?></textarea>
                        <p class="help-text">显示在系统名称下方的副标题</p>
                    </div>
                    
                    <!-- 新增页面缩放比例设置 -->
                    <div class="form-group">
                        <label for="pageScale">页面缩放比例</label>
                        <div class="range-container">
                            <input type="range" id="pageScale" min="70" max="130" step="5" 
                                   value="<?php echo esc_attr($page_scale); ?>">
                            <span class="range-value"><?php echo esc_attr($page_scale); ?>%</span>
                        </div>
                        <p class="help-text">调整前台页面的整体显示比例（70%~130%）</p>
                    </div>
                    
                    <!-- 使用说明设置 -->
                    <div class="form-group">
                        <label for="usageInstructions">使用说明</label>
                        <textarea id="usageInstructions" class="form-control" rows="4"><?php 
                            echo esc_textarea($usage_instructions); 
                        ?></textarea>
                        <p class="help-text">填写使用说明（每行一条，留空则不显示）</p>
                    </div>
                    
                    <div class="form-group">
                        <button class="btn small" id="preview-frontend">
                            <span class="dashicons dashicons-external"></span> 预览前台页面
                        </button>
                    </div>
                </div>
            </div>
            
            <div class="form-group" style="margin-top: 20px;">
                <button class="btn" id="save-settings-btn"><span class="dashicons dashicons-yes"></span> 保存所有设置</button>
            </div>
        </div>
    </div>
    
    <!-- 统计报表 -->
    <div class="tab-content" id="reports">
        <div class="form-section">
            <h3><span class="dashicons dashicons-chart-area"></span> 领取统计</h3>
            
            <div class="chart-container" style="height: 300px; background: #f8f9fa; border-radius: 10px; display: flex; align-items: center; justify-content: center; margin-bottom: 30px;">
                <div class="chart-placeholder">
                    <p style="color: #6c757d; text-align: center;">此处显示卡片领取趋势图表</p>
                    <div style="margin-top: 20px; display: flex; justify-content: center;">
                        <span class="dashicons dashicons-chart-bar" style="font-size: 48px; color: #dc3545;"></span>
                    </div>
                </div>
            </div>
            
            <div class="stats-container">
                <div class="stat-card recharge">
                    <h3><span class="dashicons dashicons-money-alt"></span> 充值卡领取统计</h3>
                    <div class="stat-value"><?php echo $recharge_stats['claimed']; ?></div>
                    <div class="stat-label">总领取次数</div>
                    
                    <div class="stat-details">
                        <div class="stat-detail">
                            今日领取 <span><?php echo $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE type = 1 AND Camilla = 1 AND FROM_UNIXTIME(create_time, '%Y-%m-%d') = CURDATE()"); ?></span>
                        </div>
                        <div class="stat-detail">
                            本周领取 <span><?php echo $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE type = 1 AND Camilla = 1 AND YEARWEEK(FROM_UNIXTIME(create_time)) = YEARWEEK(CURDATE())"); ?></span>
                        </div>
                        <div class="stat-detail">
                            本月领取 <span><?php echo $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE type = 1 AND Camilla = 1 AND MONTH(FROM_UNIXTIME(create_time)) = MONTH(CURDATE())"); ?></span>
                        </div>
                    </div>
                </div>
                
                <div class="stat-card vip">
                    <h3><span class="dashicons dashicons-awards"></span> 会员卡领取统计</h3>
                    <div class="stat-value"><?php echo $vip_stats['claimed']; ?></div>
                    <div class="stat-label">总领取次数</div>
                    
                    <div class="stat-details">
                        <div class="stat-detail">
                            今日领取 <span><?php echo $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE type = 2 AND Camilla = 1 AND FROM_UNIXTIME(create_time, '%Y-%m-%d') = CURDATE()"); ?></span>
                        </div>
                        <div class="stat-detail">
                            本周领取 <span><?php echo $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE type = 2 AND Camilla = 1 AND YEARWEEK(FROM_UNIXTIME(create_time)) = YEARWEEK(CURDATE())"); ?></span>
                        </div>
                        <div class="stat-detail">
                            本月领取 <span><?php echo $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE type = 2 AND Camilla = 1 AND MONTH(FROM_UNIXTIME(create_time)) = MONTH(CURDATE())"); ?></span>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- 添加颜色选择器库 -->
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/spectrum/1.8.1/spectrum.min.css">
<script src="https://cdnjs.cloudflare.com/ajax/libs/spectrum/1.8.1/spectrum.min.js"></script>


<style>
/* 后台管理界面样式 */
.vip-card-admin {
    max-width: 1200px;
    margin: 20px auto;
    padding: 30px;
    background: #fff;
    border-radius: 10px;
    box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
}

.admin-header {
    border-bottom: 2px solid #dc3545;
    padding-bottom: 20px;
    margin-bottom: 30px;
    display: flex;
    align-items: center;
    justify-content: space-between;
}

.admin-header h1 {
    color: #dc3545;
    display: flex;
    align-items: center;
    gap: 15px;
    margin: 0;
}

.admin-tabs {
    display: flex;
    background: #f8f9fa;
    border-radius: 8px;
    overflow: hidden;
    margin-bottom: 30px;
}

.admin-tab {
    flex: 1;
    padding: 15px 20px;
    text-align: center;
    cursor: pointer;
    transition: all 0.3s ease;
    font-weight: 600;
    color: #495057;
}

.admin-tab.active {
    background: #dc3545;
    color: white;
}

.admin-tab:hover:not(.active) {
    background: rgba(220, 53, 69, 0.1);
}

.tab-content {
    display: none;
    padding: 25px;
    background: #f8f9fa;
    border-radius: 8px;
}

.tab-content.active {
    display: block;
    animation: fadeIn 0.4s ease;
}

@keyframes fadeIn {
    from { opacity: 0; }
    to { opacity: 1; }
}

.card-type-selector {
    display: flex;
    gap: 20px;
    margin-bottom: 30px;
}

.card-type {
    flex: 1;
    padding: 25px;
    border-radius: 10px;
    text-align: center;
    cursor: pointer;
    transition: all 0.3s ease;
    background: white;
    border: 2px solid #e9ecef;
}

.card-type.active {
    border-color: #dc3545;
    box-shadow: 0 5px 15px rgba(220, 53, 69, 0.1);
}

.card-type .dashicons {
    font-size: 3.5rem;
    color: #dc3545;
    margin-bottom: 20px;
    width: auto;
    height: auto;
}

.card-type h3 {
    margin-bottom: 15px;
    color: #343a40;
}

.card-type p {
    color: #6c757d;
    line-height: 1.6;
}

.form-section {
    background: white;
    padding: 25px;
    border-radius: 10px;
    box-shadow: 0 2px 8px rgba(0, 0, 0, 0.05);
    margin-bottom: 30px;
}

.form-section h3 {
    margin-bottom: 20px;
    padding-bottom: 15px;
    border-bottom: 1px solid #e9ecef;
    color: #dc3545;
    display: flex;
    align-items: center;
    gap: 10px;
}

.form-group {
    margin-bottom: 20px;
}

.form-group label {
    display: block;
    margin-bottom: 8px;
    font-weight: 600;
    color: #495057;
}

.form-control {
    width: 100%;
    padding: 12px 15px;
    border: 1px solid #ced4da;
    border-radius: 6px;
    font-size: 16px;
    transition: border-color 0.3s;
}

.form-control:focus {
    border-color: #dc3545;
    outline: none;
    box-shadow: 0 0 0 3px rgba(220, 53, 69, 0.2);
}

textarea.form-control {
    min-height: 150px;
    resize: vertical;
}

.btn {
    display: inline-block;
    padding: 12px 25px;
    background: #dc3545;
    color: white;
    border: none;
    border-radius: 6px;
    font-size: 16px;
    font-weight: 600;
    cursor: pointer;
    transition: all 0.3s ease;
}

.btn:hover {
    background: #c82333;
    transform: translateY(-3px);
    box-shadow: 0 5px 15px rgba(220, 53, 69, 0.3);
}

.btn .dashicons {
    margin-right: 8px;
    font-size: 18px;
    vertical-align: middle;
}

.btn.small {
    padding: 8px 15px;
    font-size: 14px;
}

.stats-container {
    display: flex;
    gap: 20px;
    margin-bottom: 30px;
}

.stat-card {
    flex: 1;
    background: white;
    border-radius: 10px;
    padding: 25px;
    text-align: center;
    box-shadow: 0 3px 10px rgba(0, 0, 0, 0.05);
}

.stat-card.recharge {
    border-top: 4px solid #dc3545;
}

.stat-card.vip {
    border-top: 4px solid #e83e8c;
}

.stat-card h3 {
    margin-bottom: 20px;
    color: #495057;
    display: flex;
    align-items: center;
    justify-content: center;
    gap: 10px;
}

.stat-value {
    font-size: 2.5rem;
    font-weight: 700;
    margin-bottom: 15px;
}

.stat-card.recharge .stat-value {
    color: #dc3545;
}

.stat-card.vip .stat-value {
    color: #e83e8c;
}

.stat-label {
    color: #6c757d;
    font-size: 1.1rem;
}

.progress-container {
    height: 12px;
    background: #e9ecef;
    border-radius: 6px;
    margin: 20px 0;
    overflow: hidden;
}

.progress-bar {
    height: 100%;
    border-radius: 6px;
}

.recharge .progress-bar {
    background: linear-gradient(to right, #dc3545, #ff6b6b);
}

.vip .progress-bar {
    background: linear-gradient(to right, #e83e8c, #fd7e14);
}

.stat-details {
    display: flex;
    justify-content: space-around;
    margin-top: 20px;
    font-size: 0.9rem;
    color: #6c757d;
}

.stat-detail span {
    display: block;
    font-weight: 600;
    font-size: 1.2rem;
    margin-top: 5px;
    color: #495057;
}

.card-list {
    background: white;
    border-radius: 10px;
    overflow: hidden;
    box-shadow: 0 3px 10px rgba(0, 0, 0, 0.05);
}

.card-list-header {
    display: flex;
    justify-content: space-between;
    align-items: center;
    padding: 20px;
    background: #f8f9fa;
    border-bottom: 1px solid #e9ecef;
}

.card-list-body {
    max-height: 600px;
    overflow-y: auto;
}

.card-item {
    display: flex;
    align-items: center;
    padding: 15px 20px;
    border-bottom: 1px solid #e9ecef;
    transition: background 0.3s;
}

.card-item:hover {
    background: #f8f9fa;
}

.card-code {
    flex: 1;
    font-family: monospace;
    font-size: 1.1rem;
    font-weight: 600;
    color: #495057;
}

.card-type-badge {
    padding: 5px 10px;
    border-radius: 20px;
    font-size: 0.85rem;
    font-weight: 600;
    margin-right: 15px;
}

.recharge-badge {
    background: rgba(220, 53, 69, 0.1);
    color: #dc3545;
}

.vip-badge {
    background: rgba(232, 62, 140, 0.1);
    color: #e83e8c;
}

.card-status {
    padding: 5px 10px;
    border-radius: 20px;
    font-size: 0.85rem;
    font-weight: 600;
    margin: 0 15px;
}

.status-unclaimed {
    background: rgba(40, 167, 69, 0.1);
    color: #28a745;
}

.status-claimed {
    background: rgba(255, 193, 7, 0.1);
    color: #ffc107;
}

.status-expired {
    background: rgba(108, 117, 125, 0.1);
    color: #6c757d;
}

.status-used {
    background: rgba(13, 110, 253, 0.1);
    color: #0d6efd;
}

.card-user {
    flex: 1;
    text-align: right;
    color: #6c757d;
    font-size: 0.9rem;
}

.card-user strong {
    color: #495057;
}

.search-bar {
    display: flex;
    gap: 10px;
    margin-bottom: 15px;
}

.search-bar input {
    padding: 8px 15px;
    border: 1px solid #ced4da;
    border-radius: 6px;
    width: 250px;
}

.filter-select {
    padding: 8px 15px;
    border: 1px solid #ced4da;
    border-radius: 6px;
    background: white;
}

.theme-options {
    display: flex;
    gap: 20px;
    margin-bottom: 30px;
}

.theme-option {
    flex: 1;
    border-radius: 10px;
    overflow: hidden;
    cursor: pointer;
    border: 3px solid transparent;
    transition: all 0.3s ease;
}

.theme-option.active {
    border-color: #dc3545;
}

.theme-preview {
    height: 150px;
    display: flex;
    align-items: center;
    justify-content: center;
    color: white;
    font-weight: 600;
    font-size: 1.2rem;
}

.theme-name {
    padding: 15px;
    text-align: center;
    background: white;
}

.theme-red .theme-preview {
    background: linear-gradient(135deg, #dc3545, #e83e8c);
}

.theme-blue .theme-preview {
    background: linear-gradient(135deg, #007bff, #20c997);
}

.theme-purple .theme-preview {
    background: linear-gradient(135deg, #6f42c1, #d63384);
}

.theme-green .theme-preview {
    background: linear-gradient(135deg, #28a745, #20c997);
}

.theme-gold .theme-preview {
    background: linear-gradient(135deg, #ffc107, #fd7e14);
}

.settings-grid {
    display: grid;
    grid-template-columns: repeat(auto-fit, minmax(300px, 1fr));
    gap: 20px;
}

.setting-card {
    background: white;
    border-radius: 10px;
    padding: 25px;
    box-shadow: 0 2px 8px rgba(0, 0, 0, 0.05);
}

.setting-card h4 {
    margin-bottom: 20px;
    padding-bottom: 15px;
    border-bottom: 1px solid #e9ecef;
    color: #495057;
    display: flex;
    align-items: center;
    gap: 10px;
}

.setting-card h4 .dashicons {
    color: #dc3545;
}

.help-text {
    color: #6c757d;
    font-size: 0.9rem;
    margin-top: 5px;
}

.date-range-selector {
    display: flex;
    align-items: center;
    gap: 10px;
}

.date-range-selector span {
    color: #6c757d;
}

.no-records {
    padding: 30px;
    text-align: center;
    color: #6c757d;
}

.no-records .dashicons {
    font-size: 48px;
    margin-bottom: 15px;
}

.pagination {
    display: flex;
    justify-content: center;
    margin-top: 20px;
    padding: 15px;
    background: #f8f9fa;
    border-top: 1px solid #e9ecef;
}

.pagination .page-numbers {
    display: inline-block;
    padding: 8px 15px;
    margin: 0 3px;
    border: 1px solid #ced4da;
    border-radius: 4px;
    text-decoration: none;
    color: #495057;
    transition: all 0.3s ease;
}

.pagination .page-numbers.current {
    background: #dc3545;
    color: white;
    border-color: #dc3545;
}

.pagination .page-numbers:hover:not(.current) {
    background: #e9ecef;
}

/* 颜色选择器样式调整 */
.sp-container {
    z-index: 10000 !important;
}

/* 预览前台页面按钮样式 */
#preview-frontend {
    margin-top: 15px;
    background: #17a2b8;
}

#preview-frontend:hover {
    background: #138496;
}

/* 范围滑块容器样式 */
.range-container {
    display: flex;
    align-items: center;
    gap: 15px;
    margin-top: 8px;
}

.range-container input[type="range"] {
    flex: 1;
    height: 6px;
    border-radius: 3px;
    background: #e9ecef;
    outline: none;
    -webkit-appearance: none;
}

.range-container input[type="range"]::-webkit-slider-thumb {
    -webkit-appearance: none;
    width: 20px;
    height: 20px;
    border-radius: 50%;
    background: #dc3545;
    cursor: pointer;
    box-shadow: 0 2px 4px rgba(0,0,0,0.2);
}

.range-container .range-value {
    min-width: 50px;
    text-align: center;
    font-weight: 600;
    color: #495057;
}

@media (max-width: 768px) {
    .stats-container {
        flex-direction: column;
    }
    
    .card-type-selector {
        flex-direction: column;
    }
    
    .theme-options {
        flex-wrap: wrap;
    }
    
    .theme-option {
        min-width: calc(50% - 10px);
    }
    
    .card-list-header {
        flex-direction: column;
        gap: 15px;
        align-items: flex-start;
    }
    
    .search-bar {
        width: 100%;
        flex-wrap: wrap;
    }
    
    .search-bar input {
        width: 100%;
    }
    
    .date-range-selector {
        flex-direction: column;
        align-items: flex-start;
    }
    
    .card-list-body {
        max-height: 500px;
    }
}
</style>
<script>
jQuery(document).ready(function($) {
    // 复制短代码功能
    $('#copy-shortcode').on('click', function() {
        var temp = $('<textarea>');
        $('body').append(temp);
        temp.val('[vip_card_system]').select();
        document.execCommand('copy');
        temp.remove();
        
        // 显示复制成功反馈
        var originalText = $(this).html();
        $(this).html('<span class="dashicons dashicons-yes"></span> 已复制');
        
        setTimeout(function() {
            $('#copy-shortcode').html(originalText);
        }, 2000);
    });
});
</script>



<?php
// 加载WordPress后台尾部
require_once(ABSPATH . 'wp-admin/admin-footer.php'); 