<?php
// admin/diagnostic.php
if (!defined('ABSPATH')) {
    exit; // 禁止直接访问
}

// 权限验证（仅管理员可访问）
if (!current_user_can('manage_options')) {
    wp_die(__('抱歉，您没有权限访问此页面'));
}

global $title, $wpdb;
$title = '数据库诊断'; // 设置页面标题

// 加载WordPress后台头部
require_once(ABSPATH . 'wp-admin/admin-header.php');

// 数据库表名
$table_name = $wpdb->prefix . 'cao_cdk_tbl';

// 执行诊断
$db_results = vip_card_system_check_database();

// 修复数据库功能
if (isset($_POST['fix_database'])) {
    // 创建表SQL - 添加新字段
    $create_table_sql = "CREATE TABLE IF NOT EXISTS `$table_name` (
        `id` int(11) NOT NULL AUTO_INCREMENT,
        `order_id` bigint(20) unsigned NOT NULL DEFAULT '0' COMMENT '关联订单ID',
        `type` int(11) NOT NULL DEFAULT '1' COMMENT '1=充值卡,2=会员卡',
        `amount` decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '金额',
        `create_time` int(11) NOT NULL DEFAULT '0' COMMENT '创建时间',
        `expiry_time` int(11) NOT NULL DEFAULT '0' COMMENT '卡密过期时间',
        `claim_time` int(11) NOT NULL DEFAULT '0' COMMENT '领取时间',
        `code` varchar(100) NOT NULL DEFAULT '' COMMENT '卡号',
        `info` varchar(255) NOT NULL DEFAULT '' COMMENT 'VIP天数',
        `user` text NOT NULL COMMENT '用户信息(JSON格式)',
        `status` int(11) NOT NULL DEFAULT '0' COMMENT '0=未使用 1=已使用',
        `Camilla` int(11) NOT NULL DEFAULT '0' COMMENT '0=未领取 1=已领取',
        PRIMARY KEY (`id`),
        UNIQUE KEY `code` (`code`)
    ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;";
    
    // 执行创建表
    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($create_table_sql);
    
    // 检查并添加缺失字段（如果不存在）
    $fields_to_check = [
        'user' => "ALTER TABLE $table_name ADD user text NOT NULL COMMENT '用户信息(JSON格式)'",
        'claim_time' => "ALTER TABLE $table_name ADD claim_time int(11) NOT NULL DEFAULT '0' COMMENT '领取时间'",
        'order_id' => "ALTER TABLE $table_name ADD order_id bigint(20) unsigned NOT NULL DEFAULT '0' COMMENT '关联订单ID'",
        'expiry_time' => "ALTER TABLE $table_name ADD expiry_time int(11) NOT NULL DEFAULT '0' COMMENT '卡密过期时间'"
    ];
    
    $added_fields = [];
    
    foreach ($fields_to_check as $field => $sql) {
        $field_check = $wpdb->get_row("SHOW COLUMNS FROM $table_name LIKE '$field'");
        if (!$field_check) {
            $wpdb->query($sql);
            $added_fields[] = $field;
        }
    }
    
    // 显示成功消息
    $message = '<div class="notice notice-success"><p>数据库表已成功修复！</p>';
    
    if (!empty($added_fields)) {
        $message .= '<p>已添加字段：' . implode(', ', $added_fields) . '</p>';
    } else {
        $message .= '<p>所有字段已存在，无需添加。</p>';
    }
    
    $message .= '</div>';
    echo $message;
}

?>

<div class="vip-card-admin">
    <h1>数据库诊断</h1>
    
    <?php if (isset($fix_message)) echo $fix_message; ?>
    
    <div class="diagnostic-section">
        <div class="diagnostic-card">
            <h2>数据库状态</h2>
            
            <div class="status-item">
                <span class="status-label">卡密表状态:</span>
                <span class="status-value <?php echo $db_results['table_exists'] ? 'status-success' : 'status-error'; ?>">
                    <?php echo $db_results['table_exists'] ? '已存在' : '不存在'; ?>
                </span>
            </div>
            
            <?php if (!$db_results['table_exists']) : ?>
                <div class="error-notice">
                    <p>错误: 数据库表 <code><?php echo $table_name; ?></code> 不存在！</p>
                    <form method="post">
                        <button type="submit" name="fix_database" class="button button-primary">创建缺失表</button>
                    </form>
                </div>
            <?php endif; ?>
            
            <?php if (!empty($db_results['errors'])) : ?>
                <div class="error-notice">
                    <h3>数据库错误:</h3>
                    <ul>
                        <?php foreach ($db_results['errors'] as $error) : ?>
                            <li><?php echo esc_html($error); ?></li>
                        <?php endforeach; ?>
                    </ul>
                </div>
            <?php endif; ?>
        </div>
        
        <div class="diagnostic-card">
            <h2>数据统计</h2>
            
            <?php if ($db_results['table_exists']) : ?>
                <div class="stats-grid">
                    <div class="stat-item">
                        <div class="stat-label">卡密总数</div>
                        <div class="stat-value"><?php echo $db_results['card_count']; ?></div>
                    </div>
                    
                    <div class="stat-item">
                        <div class="stat-label">充值卡数量</div>
                        <div class="stat-value"><?php echo $db_results['recharge_count']; ?></div>
                    </div>
                    
                    <div class="stat-item">
                        <div class="stat-label">VIP卡数量</div>
                        <div class="stat-value"><?php echo $db_results['vip_count']; ?></div>
                    </div>
                    
                    <div class="stat-item">
                        <div class="stat-label">可用卡密</div>
                        <div class="stat-value"><?php echo $db_results['available_count']; ?></div>
                    </div>
                    
                    <div class="stat-item">
                        <div class="stat-label">已领取卡密</div>
                        <div class="stat-value"><?php echo $db_results['claimed_count']; ?></div>
                    </div>
                    
                    <div class="stat-item">
                        <div class="stat-label">已使用卡密</div>
                        <div class="stat-value"><?php echo $db_results['used_count']; ?></div>
                    </div>
                </div>
            <?php else : ?>
                <p class="no-data">无可用数据 - 数据库表不存在</p>
            <?php endif; ?>
        </div>
        
        <div class="diagnostic-card">
            <h2>数据库工具</h2>
            
            <div class="tool-section">
                <h3>修复数据库表</h3>
                <p>如果数据库表结构存在问题，可以尝试修复表结构：</p>
                <form method="post">
                    <button type="submit" name="fix_database" class="button button-primary">修复数据库表</button>
                </form>
            </div>
            
            <div class="tool-section">
                <h3>优化数据库表</h3>
                <p>优化数据库表可以提高系统性能：</p>
                <form method="post">
                    <button type="submit" name="optimize_table" class="button">优化表</button>
                </form>
            </div>
            
            <?php if (isset($_POST['optimize_table']) && $db_results['table_exists']) : ?>
                <?php
                try {
                    $wpdb->query("OPTIMIZE TABLE $table_name");
                    echo '<div class="notice notice-success"><p>表已成功优化！</p></div>';
                } catch (Exception $e) {
                    echo '<div class="notice notice-error"><p>优化失败: ' . esc_html($e->getMessage()) . '</p></div>';
                }
                ?>
            <?php endif; ?>
        </div>
    </div>
    
    <div class="sql-section">
        <h2>SQL查询工具</h2>
        <form method="post">
            <div class="form-group">
                <label for="sql-query">输入SQL查询：</label>
                <textarea id="sql-query" name="sql_query" rows="4" class="widefat" placeholder="SELECT * FROM $table_name LIMIT 10"></textarea>
            </div>
            <div class="form-group">
                <button type="submit" name="execute_sql" class="button button-primary">执行查询</button>
            </div>
        </form>
        
        <?php if (isset($_POST['execute_sql']) && !empty($_POST['sql_query'])) : ?>
            <?php
            $sql_query = stripslashes($_POST['sql_query']);
            $results = [];
            $error = '';
            
            try {
                // 只允许SELECT查询
                if (stripos(trim($sql_query), 'SELECT') === 0) {
                    $results = $wpdb->get_results($sql_query, ARRAY_A);
                } else {
                    throw new Exception("只允许执行SELECT查询");
                }
            } catch (Exception $e) {
                $error = $e->getMessage();
            }
            ?>
            
            <div class="query-results">
                <h3>查询结果：</h3>
                
                <?php if (!empty($error)) : ?>
                    <div class="notice notice-error">
                        <p>查询错误: <?php echo esc_html($error); ?></p>
                    </div>
                <?php elseif (empty($results)) : ?>
                    <div class="notice notice-warning">
                        <p>查询成功，但没有返回结果</p>
                    </div>
                <?php else : ?>
                    <div class="table-container">
                        <table class="widefat fixed" cellspacing="0">
                            <thead>
                                <tr>
                                    <?php foreach (array_keys($results[0]) as $column) : ?>
                                        <th><?php echo esc_html($column); ?></th>
                                    <?php endforeach; ?>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($results as $row) : ?>
                                    <tr>
                                        <?php foreach ($row as $value) : ?>
                                            <td><?php echo esc_html($value); ?></td>
                                        <?php endforeach; ?>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                    
                    <div class="result-stats">
                        返回了 <?php echo count($results); ?> 行数据
                    </div>
                <?php endif; ?>
            </div>
        <?php endif; ?>
    </div>
</div>

<style>
.vip-card-admin {
    max-width: 1200px;
    margin: 20px auto;
    padding: 20px;
}

.diagnostic-section {
    display: grid;
    grid-template-columns: repeat(auto-fit, minmax(300px, 1fr));
    gap: 20px;
    margin-bottom: 30px;
}

.diagnostic-card {
    background: #fff;
    border-radius: 4px;
    padding: 20px;
    box-shadow: 0 1px 1px rgba(0,0,0,.04);
    border-left: 4px solid #0073aa;
}

.status-item {
    display: flex;
    justify-content: space-between;
    padding: 10px 0;
    border-bottom: 1px solid #eee;
}

.status-label {
    font-weight: 600;
}

.status-value {
    font-weight: bold;
}

.status-success {
    color: #28a745;
}

.status-error {
    color: #dc3545;
}

.error-notice {
    background: #f8d7da;
    border-left: 4px solid #dc3545;
    padding: 15px;
    margin-top: 15px;
    border-radius: 4px;
}

.stats-grid {
    display: grid;
    grid-template-columns: repeat(2, 1fr);
    gap: 15px;
    margin-top: 15px;
}

.stat-item {
    background: #f8f9fa;
    padding: 15px;
    border-radius: 4px;
    text-align: center;
}

.stat-label {
    font-size: 0.9rem;
    color: #6c757d;
    margin-bottom: 5px;
}

.stat-value {
    font-size: 1.5rem;
    font-weight: bold;
    color: #0073aa;
}

.tool-section {
    padding: 15px 0;
    border-bottom: 1px solid #eee;
}

.tool-section:last-child {
    border-bottom: none;
}

.sql-section {
    background: #fff;
    padding: 20px;
    border-radius: 4px;
    box-shadow: 0 1px 1px rgba(0,0,0,.04);
    margin-bottom: 30px;
}

.form-group {
    margin-bottom: 15px;
}

.query-results {
    margin-top: 20px;
}

.table-container {
    overflow-x: auto;
    max-height: 400px;
    overflow-y: auto;
    margin: 15px 0;
    border: 1px solid #e5e5e5;
}

table.widefat {
    width: 100%;
    border-collapse: collapse;
}

table.widefat th, table.widefat td {
    padding: 8px 10px;
    border: 1px solid #e5e5e5;
    text-align: left;
}

table.widefat th {
    background: #f8f8f8;
    position: sticky;
    top: 0;
}

.result-stats {
    text-align: right;
    font-size: 0.9rem;
    color: #6c757d;
    padding: 5px 10px;
    background: #f8f9fa;
    border-top: 1px solid #e5e5e5;
}

.no-data {
    text-align: center;
    padding: 20px;
    color: #6c757d;
    font-style: italic;
}

/* 响应式调整 */
@media (max-width: 768px) {
    .diagnostic-section {
        grid-template-columns: 1fr;
    }
    
    .stats-grid {
        grid-template-columns: 1fr;
    }
}
</style>