<?php
// reports.php
if (!defined('ABSPATH')) {
    exit; // 禁止直接访问
}

// 权限验证（仅管理员可访问）
if (!current_user_can('manage_options')) {
    wp_die(__('抱歉，您没有权限访问此页面'));
}

global $wpdb, $title;
$title = 'VIP卡系统统计报表'; // 设置页面标题

// 加载WordPress后台头部
require_once(ABSPATH . 'wp-admin/admin-header.php');

// 数据库表名
$table_name = $wpdb->prefix . 'cao_cdk_tbl';

// 获取时间范围参数（默认最近30天）
$start_date = isset($_GET['start_date']) ? sanitize_text_field($_GET['start_date']) : date('Y-m-d', strtotime('-30 days'));
$end_date = isset($_GET['end_date']) ? sanitize_text_field($_GET['end_date']) : date('Y-m-d');

// 获取卡密统计数据 - 基于领取时间
function get_card_stats($type, $start_date, $end_date) {
    global $wpdb;
    $table_name = $wpdb->prefix . 'cao_cdk_tbl';
    
    return [
        'claimed' => $wpdb->get_var($wpdb->prepare(
            "SELECT COUNT(*) FROM $table_name 
             WHERE type = %d 
             AND Camilla = 1 
             AND claim_time >= UNIX_TIMESTAMP(%s) 
             AND claim_time < UNIX_TIMESTAMP(%s) + 86400",
            $type, $start_date, $end_date
        )),
        'available' => $wpdb->get_var($wpdb->prepare(
            "SELECT COUNT(*) FROM $table_name 
             WHERE type = %d 
             AND Camilla = 0 
             AND DATE(FROM_UNIXTIME(create_time)) BETWEEN %s AND %s",
            $type, $start_date, $end_date
        ))
    ];
}

// 获取时间趋势数据 - 基于领取时间
function get_trend_data($type, $start_date, $end_date) {
    global $wpdb;
    $table_name = $wpdb->prefix . 'cao_cdk_tbl';
    
    $results = $wpdb->get_results(
        $wpdb->prepare(
            "SELECT 
                DATE(FROM_UNIXTIME(claim_time)) AS date,
                COUNT(*) AS claimed
             FROM $table_name
             WHERE type = %d
             AND Camilla = 1
             AND claim_time >= UNIX_TIMESTAMP(%s)
             AND claim_time < UNIX_TIMESTAMP(%s) + 86400
             GROUP BY DATE(FROM_UNIXTIME(claim_time))
             ORDER BY DATE(FROM_UNIXTIME(claim_time)) DESC", // 修改为DESC倒序
            $type, $start_date, $end_date
        ),
        ARRAY_A
    );
    
    // 填充缺失的日期（现在按倒序填充）
    $trend_data = [];
    $current_date = $end_date;
    
    while ($current_date >= $start_date) {
        $found = false;
        foreach ($results as $row) {
            if ($row['date'] === $current_date) {
                $trend_data[] = $row;
                $found = true;
                break;
            }
        }
        
        if (!$found) {
            $trend_data[] = [
                'date' => $current_date,
                'claimed' => 0
            ];
        }
        
        $current_date = date('Y-m-d', strtotime($current_date . ' -1 day'));
    }
    
    return $trend_data;
}

// 获取数据
$recharge_stats = get_card_stats(1, $start_date, $end_date);
$vip_stats = get_card_stats(2, $start_date, $end_date);
$recharge_trend = get_trend_data(1, $start_date, $end_date);
$vip_trend = get_trend_data(2, $start_date, $end_date);

// 准备图表数据（保持图表顺序为从过去到现在）
$chart_labels = [];
$recharge_claimed_data = [];
$vip_claimed_data = [];

// 反转数组用于图表（从过去到现在）
$chart_recharge_trend = array_reverse($recharge_trend);
$chart_vip_trend = array_reverse($vip_trend);

foreach ($chart_recharge_trend as $index => $recharge) {
    $chart_labels[] = date('m-d', strtotime($recharge['date']));
    $recharge_claimed_data[] = $recharge['claimed'];
    
    // 确保VIP数据与充值卡数据日期对齐
    $vip_claimed = 0;
    if (isset($chart_vip_trend[$index]) && $chart_vip_trend[$index]['date'] === $recharge['date']) {
        $vip_claimed = $chart_vip_trend[$index]['claimed'];
    }
    $vip_claimed_data[] = $vip_claimed;
}
?>

<div class="vip-card-admin">
    <h1>VIP卡系统统计报表</h1>
    
    <!-- 时间筛选表单 -->
    <div class="filter-section">
        <form method="get" action="">
            <input type="hidden" name="page" value="vip-card-reports">
            <div class="date-range">
                <label for="start_date">开始日期：</label>
                <input type="date" id="start_date" name="start_date" value="<?php echo esc_attr($start_date); ?>">
                
                <label for="end_date">结束日期：</label>
                <input type="date" id="end_date" name="end_date" value="<?php echo esc_attr($end_date); ?>">
                
                <button type="submit" class="button button-primary">筛选</button>
                <button type="button" id="reset-dates" class="button">重置</button>
            </div>
        </form>
    </div>
    
    <!-- 数据概览卡片 -->
    <div class="stats-overview">
        <div class="stat-card">
            <h3>充值卡统计</h3>
            <div class="stat-value"><?php echo $recharge_stats['claimed']; ?></div>
            <div class="stat-label">已领取数量</div>
            <div class="stat-detail">可用数量: <?php echo $recharge_stats['available']; ?></div>
        </div>
        
        <div class="stat-card">
            <h3>会员卡统计</h3>
            <div class="stat-value"><?php echo $vip_stats['claimed']; ?></div>
            <div class="stat-label">已领取数量</div>
            <div class="stat-detail">可用数量: <?php echo $vip_stats['available']; ?></div>
        </div>
        
        <div class="stat-card">
            <h3>总领取量</h3>
            <div class="stat-value">
                <?php
                $total_claimed = $recharge_stats['claimed'] + $vip_stats['claimed'];
                echo $total_claimed;
                ?>
            </div>
            <div class="stat-label">领取总数</div>
        </div>
    </div>
    
    <!-- 趋势图表 -->
    <div class="chart-section">
        <h2>卡密领取趋势</h2>
        <div class="chart-container">
            <canvas id="trendChart" height="400"></canvas>
        </div>
    </div>
    
    <!-- 详细数据表格（现在按日期倒序显示） -->
    <div class="table-section">
        <h2>详细数据（最新日期在最上面）</h2>
        <table class="widefat fixed" cellspacing="0">
            <thead>
                <tr>
                    <th>日期</th>
                    <th>充值卡领取量</th>
                    <th>会员卡领取量</th>
                    <th>总领取量</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($recharge_trend as $index => $recharge) : 
                    $vip_claimed = isset($vip_trend[$index]) ? $vip_trend[$index]['claimed'] : 0;
                    $total_claimed = $recharge['claimed'] + $vip_claimed;
                ?>
                <tr>
                    <td><?php echo esc_html($recharge['date']); ?></td>
                    <td><?php echo $recharge['claimed']; ?></td>
                    <td><?php echo $vip_claimed; ?></td>
                    <td><?php echo $total_claimed; ?></td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
</div>

<style>
/* 基础样式 */
.vip-card-admin {
    max-width: 1200px;
    margin: 20px auto;
    padding: 20px;
}

.filter-section {
    background: #fff;
    padding: 20px;
    border-radius: 4px;
    box-shadow: 0 1px 1px rgba(0,0,0,.04);
    margin-bottom: 20px;
}

.date-range {
    display: flex;
    align-items: center;
    gap: 15px;
    flex-wrap: wrap;
}

.date-range label {
    font-weight: 600;
}

.date-range input[type="date"] {
    padding: 5px 10px;
    border: 1px solid #ddd;
    border-radius: 4px;
}

.stats-overview {
    display: grid;
    grid-template-columns: repeat(auto-fit, minmax(300px, 1fr));
    gap: 20px;
    margin-bottom: 30px;
}

.stat-card {
    background: #fff;
    border-radius: 4px;
    padding: 20px;
    box-shadow: 0 1px 1px rgba(0,0,0,.04);
    border-left: 4px solid #0073aa;
}

.stat-card h3 {
    margin-top: 0;
    color: #0073aa;
}

.stat-value {
    font-size: 2.5rem;
    font-weight: bold;
    margin: 10px 0;
}

.stat-label {
    font-size: 1.1rem;
    color: #666;
    margin-bottom: 10px;
}

.stat-detail {
    font-size: 1rem;
    color: #444;
    border-top: 1px solid #eee;
    padding-top: 10px;
    margin-top: 10px;
}

.chart-section {
    background: #fff;
    padding: 20px;
    border-radius: 4px;
    box-shadow: 0 1px 1px rgba(0,0,0,.04);
    margin-bottom: 30px;
}

.chart-container {
    height: 400px;
    position: relative;
}

.table-section {
    background: #fff;
    padding: 20px;
    border-radius: 4px;
    box-shadow: 0 1px 1px rgba(0,0,0,.04);
    overflow-x: auto;
}

table.widefat {
    border: 1px solid #e5e5e5;
    box-shadow: 0 1px 1px rgba(0,0,0,.04);
    width: 100%;
}

table.widefat th {
    background: #f8f8f8;
    font-weight: bold;
}

table.widefat th, table.widefat td {
    padding: 10px;
    border: 1px solid #e5e5e5;
    text-align: center;
}

/* 响应式调整 */
@media (max-width: 782px) {
    .stats-overview {
        grid-template-columns: 1fr;
    }
    
    .date-range {
        flex-direction: column;
        align-items: flex-start;
    }
    
    .chart-container {
        height: 300px;
    }
}
</style>

<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
<script>
jQuery(document).ready(function($) {
    // 重置日期按钮
    $('#reset-dates').on('click', function() {
        $('#start_date').val('');
        $('#end_date').val('');
        $('form').submit();
    });
    
    // 初始化图表
    const ctx = document.getElementById('trendChart').getContext('2d');
    
    // 确保数据对齐
    const labels = <?php echo json_encode($chart_labels); ?>;
    const rechargeData = <?php echo json_encode($recharge_claimed_data); ?>;
    const vipData = <?php echo json_encode($vip_claimed_data); ?>;
    
    // 创建图表
    const trendChart = new Chart(ctx, {
        type: 'line',
        data: {
            labels: labels,
            datasets: [
                {
                    label: '充值卡领取量',
                    data: rechargeData,
                    borderColor: '#dc3545',
                    backgroundColor: 'rgba(220, 53, 69, 0.1)',
                    borderWidth: 3,
                    pointRadius: 5,
                    pointBackgroundColor: '#dc3545',
                    tension: 0.1,
                    fill: true
                },
                {
                    label: '会员卡领取量',
                    data: vipData,
                    borderColor: '#6f42c1',
                    backgroundColor: 'rgba(111, 66, 193, 0.1)',
                    borderWidth: 3,
                    pointRadius: 5,
                    pointBackgroundColor: '#6f42c1',
                    tension: 0.1,
                    fill: true
                }
            ]
        },
        options: {
            responsive: true,
            maintainAspectRatio: false,
            plugins: {
                legend: {
                    position: 'top',
                    labels: {
                        font: {
                            size: 14
                        }
                    }
                },
                title: {
                    display: true,
                    text: '卡密领取趋势 (' + '<?php echo $start_date; ?>' + ' 至 ' + '<?php echo $end_date; ?>' + ')',
                    font: {
                        size: 16,
                        weight: 'bold'
                    },
                    padding: 20
                },
                tooltip: {
                    backgroundColor: 'rgba(0, 0, 0, 0.7)',
                    padding: 12,
                    titleFont: {
                        size: 14
                    },
                    bodyFont: {
                        size: 14
                    }
                }
            },
            scales: {
                y: {
                    beginAtZero: true,
                    title: {
                        display: true,
                        text: '领取数量',
                        font: {
                            size: 14,
                            weight: 'bold'
                        }
                    },
                    ticks: {
                        font: {
                            size: 12
                        }
                    },
                    grid: {
                        color: 'rgba(0, 0, 0, 0.05)'
                    }
                },
                x: {
                    title: {
                        display: true,
                        text: '日期',
                        font: {
                            size: 14,
                            weight: 'bold'
                        }
                    },
                    ticks: {
                        font: {
                            size: 12
                        }
                    },
                    grid: {
                        display: false
                    }
                }
            },
            interaction: {
                intersect: false,
                mode: 'index'
            },
            animation: {
                duration: 1000,
                easing: 'easeOutQuart'
            }
        }
    });
});
</script>