//assets/js/admin.js
jQuery(document).ready(function($) {
    // 标签切换功能
    $('.admin-tab').on('click', function() {
        // 移除所有active状态
        $('.admin-tab').removeClass('active');
        $('.tab-content').removeClass('active');
        
        // 设置当前active状态
        $(this).addClass('active');
        $('#' + $(this).data('tab')).addClass('active');
    });
    
    // 主题选择
    $('.theme-option').on('click', function() {
        const theme = $(this).data('theme');
        
        // 更新UI
        $('.theme-option').removeClass('active');
        $(this).addClass('active');
        
        // 显示选择状态
        const themeName = $(this).find('.theme-name').text();
        $('#selected-theme-name').text(themeName);
        $('.theme-selection-status').show();
    });
    
    // 初始化颜色选择器
    $('.color-field').spectrum({
        preferredFormat: "hex",
        showInput: true,
        showPalette: true,
        palette: [
            ["#ffffff", "#f8f9fa", "#e9ecef", "#dee2e6"],
            ["#dc3545", "#e83e8c", "#6f42c1", "#007bff"],
            ["#28a745", "#20c997", "#17a2b8", "#ffc107"],
            ["#fd7e14", "#343a40", "#6c757d", "#adb5bd"]
        ]
    });
    
    // 倒计时模式切换
    $('input[name="countdownMode"]').change(function() {
        if ($(this).val() === 'hour') {
            $('#hour-mode-settings').show();
            $('#date-mode-settings').hide();
        } else {
            $('#hour-mode-settings').hide();
            $('#date-mode-settings').show();
        }
    });
    
    // 页面缩放滑块实时更新
    $('#pageScale').on('input', function() {
        $(this).siblings('.range-value').text($(this).val() + '%');
    });
    
    // 预览前台页面
    $('#preview-frontend').on('click', function() {
        const frontendName = $('#frontendName').val() || 'VIP尊享卡领取中心';
        const welcomeMessage = $('#welcomeMessage').val() || '尊贵用户专享特权，领取您的专属VIP卡或充值卡';
        const usageInstructions = $('#usageInstructions').val() || '';
        const pageScale = $('#pageScale').val() || '100';
        
        // 构造预览内容
        let previewContent = `前台页面预览 (缩放: ${pageScale}%):\n\n系统名称: ${frontendName}\n欢迎消息: ${welcomeMessage}`;
        
        if (usageInstructions) {
            const instructionsList = usageInstructions.split('\n').filter(line => line.trim() !== '');
            previewContent += '\n\n使用说明:';
            instructionsList.forEach((instruction, index) => {
                previewContent += `\n${index + 1}. ${instruction.trim()}`;
            });
        }
        
        // 创建预览弹窗
        const $previewModal = $(
            `<div class="preview-modal" style="position:fixed;top:0;left:0;width:100%;height:100%;background:rgba(0,0,0,0.7);z-index:9999;display:flex;align-items:center;justify-content:center;">
                <div style="background:white;padding:30px;border-radius:10px;max-width:90%;max-height:90%;overflow:auto;">
                    <pre style="white-space:pre-wrap;font-family:inherit;">${previewContent}</pre>
                    <div style="text-align:center;margin-top:20px;">
                        <button class="btn close-preview" style="background:#dc3545;color:white;border:none;padding:10px 20px;border-radius:5px;cursor:pointer;">关闭预览</button>
                    </div>
                </div>
            </div>`
        );
        
        // 添加关闭功能
        $previewModal.find('.close-preview').on('click', function() {
            $previewModal.remove();
        });
        
        // 添加到页面
        $('body').append($previewModal);
    });
    
    // 开启新一轮活动
    $('#new-activity-btn').off('click').on('click', function() {
        const button = $(this);
        const originalHtml = button.html();
        button.html('<span class="spinner"></span> ' + vipCardSystem.i18n.processing).prop('disabled', true);
        
        // 清除之前可能存在的通知
        $('.vip-card-admin .notice').remove();
        
        // 发送AJAX请求
        $.post(vipCardSystem.ajaxUrl, {
            action: 'vip_card_system_reset_activity',
            nonce: vipCardSystem.nonce
        }, function(response) {
            console.log('活动重置响应:', response);
            
            if (response.success) {
                // 插入成功通知
                $('<div class="notice notice-success is-dismissible"><p>' + response.data.message + '</p></div>')
                    .insertBefore('.vip-card-admin')
                    .delay(5000)
                    .fadeOut(1000, function() {
                        $(this).remove();
                    });
            } else {
                // 错误通知
                $('<div class="notice notice-error is-dismissible"><p>' + response.data.message + '</p></div>')
                    .insertBefore('.vip-card-admin');
            }
        }).fail(function(jqXHR, textStatus, errorThrown) {
            console.error('活动重置失败:', textStatus, errorThrown);
            $('<div class="notice notice-error is-dismissible"><p>请求失败: ' + textStatus + ' - ' + errorThrown + '</p></div>')
                .insertBefore('.vip-card-admin');
        }).always(function() {
            // 确保总是恢复按钮状态
            button.html(originalHtml).prop('disabled', false);
        });
    });
    
    // 保存设置功能
    $('#save-settings-btn').off('click').on('click', function() {
        // 获取选中的主题
        const selectedTheme = $('.theme-option.active').data('theme');
        
        // 获取选中的用户角色
        const selectedRoles = [];
        $('#userRoles option:selected').each(function() {
            selectedRoles.push($(this).val());
        });
        
        // 获取卡片背景色
        const rechargeCardBg = $('#recharge-card-bg').val();
        const vipCardBg = $('#vip-card-bg').val();
        
        // 获取使用说明
        const usageInstructions = $('#usageInstructions').val();
        
        // 获取页面缩放比例
        const pageScale = $('#pageScale').val();

        // 获取倒计时设置
        const countdownMode = $('input[name="countdownMode"]:checked').val();
        const countdownTime = $('input[name="countdownTime"]').val();
        const countdownEndDate = $('input[name="countdownEndDate"]').val();
        const countdownEndTime = $('input[name="countdownEndTime"]').val();
        
        const settings = {
            theme: selectedTheme,
            userRoles: selectedRoles,
            countdownMode: countdownMode,
            countdownTime: countdownTime,
            countdownEndDate: countdownEndDate,
            countdownEndTime: countdownEndTime,
            adminEmail: $('#adminEmail').val(),
            frontendName: $('#frontendName').val(),
            welcomeMessage: $('#welcomeMessage').val(),
            usageInstructions: usageInstructions,
            pageScale: pageScale,
            rechargeCardBg: rechargeCardBg,
            vipCardBg: vipCardBg,
            ipRestriction: $('#ip-restriction').is(':checked') ? 1 : 0,
            timeRestriction: $('#time-restriction').is(':checked') ? 1 : 0,
            emailNotification: $('#email-notification').is(':checked') ? 1 : 0,
            lowStockNotification: $('#low-stock-notification').is(':checked') ? 1 : 0
        };
        
        // 显示加载状态
        const button = $(this);
        const originalHtml = button.html();
        button.html('<span class="spinner"></span> ' + vipCardSystem.i18n.processing).prop('disabled', true);
        
        // 清除之前可能存在的通知
        $('.vip-card-admin .notice').remove();
        
        console.log('正在保存设置:', settings);
        
        // 发送AJAX请求保存设置
        $.post(vipCardSystem.ajaxUrl, {
            action: 'vip_card_system_save_settings',
            nonce: vipCardSystem.nonce,
            settings: JSON.stringify(settings)
        }, function(response) {
            console.log('保存响应:', response);
            
            if (response.success) {
                // 插入成功通知
                $('<div class="notice notice-success is-dismissible"><p>设置已保存成功！</p></div>')
                    .insertBefore('.vip-card-admin')
                    .delay(5000)
                    .fadeOut(1000, function() {
                        $(this).remove();
                    });
            } else {
                // 错误通知
                $('<div class="notice notice-error is-dismissible"><p>保存失败: ' + (response.data.message || '未知错误') + '</p></div>')
                    .insertBefore('.vip-card-admin');
            }
        }).fail(function(jqXHR, textStatus, errorThrown) {
            console.error('保存失败:', textStatus, errorThrown);
            $('<div class="notice notice-error is-dismissible"><p>' + vipCardSystem.i18n.error + ': ' + textStatus + '</p></div>')
                .insertBefore('.vip-card-admin');
        }).always(function() {
            // 恢复按钮状态
            button.html(originalHtml).prop('disabled', false);
        });
    });
    
    // 添加spinner动画样式
    $('<style>')
        .prop('type', 'text/css')
        .html(`
            .spinner {
                display: inline-block;
                width: 16px;
                height: 16px;
                vertical-align: middle;
                border: 2px solid rgba(255,255,255,.3);
                border-radius: 50%;
                border-top-color: #fff;
                animation: spin 1s ease-in-out infinite;
                margin-right: 8px;
            }
            
            @keyframes spin {
                to { transform: rotate(360deg); }
            }
            
            /* 通知样式 */
            .notice {
                padding: 15px;
                border-left: 4px solid;
                margin-bottom: 20px;
                box-shadow: 0 1px 1px rgba(0,0,0,.04);
            }
            
            .notice-success {
                border-color: #46b450;
                background-color: #f7fff7;
            }
            
            .notice-error {
                border-color: #dc3232;
                background-color: #ffeaea;
            }
            
            .is-dismissible {
                position: relative;
                padding-right: 38px;
            }
            
            .notice-dismiss {
                text-decoration: none;
                float: right;
                margin-top: -5px;
            }
            
            /* 预览模态框样式 */
            .preview-modal pre {
                font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
                font-size: 14px;
                line-height: 1.6;
                color: #333;
                background: #f8f9fa;
                padding: 20px;
                border-radius: 5px;
                max-height: 70vh;
                overflow: auto;
            }
            
            .preview-modal .btn {
                background: #dc3545;
                color: white;
                border: none;
                padding: 10px 20px;
                border-radius: 5px;
                cursor: pointer;
                font-weight: 600;
                transition: background 0.3s;
            }
            
            .preview-modal .btn:hover {
                background: #c82333;
            }
        `)
        .appendTo('head');
});