<?php
// public/display.php
$theme = get_option('vip_card_system_theme', 'red');
$frontend_name = get_option('vip_card_system_frontend_name', 'VIP尊享卡领取中心');
$welcome_message = get_option('vip_card_system_welcome_message', '尊贵用户专享特权，领取您的专属VIP卡或充值卡');

// 获取倒计时设置
$countdown_mode = get_option('vip_card_system_countdown_mode', 'hour');
$countdown_hours = get_option('vip_card_system_countdown_time', 24);
$end_date = get_option('vip_card_system_countdown_end_date', date('Y-m-d', strtotime('+1 day')));
$end_time = get_option('vip_card_system_countdown_end_time', '23:59');

// 获取页面缩放比例
$page_scale = get_option('vip_card_system_page_scale', 100) / 100;

// 卡片背景色设置
$recharge_card_bg = get_option('vip_card_system_recharge_card_bg', '');
$vip_card_bg = get_option('vip_card_system_vip_card_bg', '');

// 获取使用说明设置
$usage_instructions = get_option('vip_card_system_usage_instructions', '');
$instructions_list = !empty($usage_instructions) ? explode("\n", $usage_instructions) : [];

// 检查用户是否已领取卡密
$user_id = get_current_user_id();
$has_claimed = false;
$claimed_type = '';

if ($user_id) {
    global $wpdb;
    $table_name = $wpdb->prefix . 'cao_cdk_tbl';
    
    $claimed_card = $wpdb->get_row(
        $wpdb->prepare(
            "SELECT type FROM $table_name 
             WHERE Camilla = 1 
             AND user LIKE %s
             LIMIT 1",
            '%"user_id":' . $user_id . '%'
        )
    );
    
    if ($claimed_card) {
        $has_claimed = true;
        $claimed_type = ($claimed_card->type == 1) ? 'recharge' : 'vip';
    }
}

// 对比度计算函数
function vip_card_system_get_contrast_color($hexColor) {
    // 移除 # 号
    $hexColor = str_replace('#', '', $hexColor);
    
    // 如果是3位HEX，转换为6位
    if (strlen($hexColor) == 3) {
        $hexColor = $hexColor[0].$hexColor[0].$hexColor[1].$hexColor[1].$hexColor[2].$hexColor[2];
    }
    
    // 转换为RGB
    $r = hexdec(substr($hexColor, 0, 2));
    $g = hexdec(substr($hexColor, 2, 2));
    $b = hexdec(substr($hexColor, 4, 2));
    
    // 计算YIQ值
    $yiq = (($r * 299) + ($g * 587) + ($b * 114)) / 1000;
    
    // 根据亮度返回黑色或白色
    return ($yiq >= 128) ? '#333' : '#fff';
}

// 准备日期模式的数据
$end_datetime = $end_date . ' ' . $end_time;
?>

<div class="vip-card-system-scaling" style="transform: scale(<?php echo $page_scale; ?>); transform-origin: top center;">
    <div class="vip-card-system theme-<?php echo esc_attr($theme); ?>">
        <div class="card-header">
            <h1><?php echo esc_html($frontend_name); ?></h1>
            <p><?php echo esc_html($welcome_message); ?></p>
        </div>
        
        <div class="card-container">
            <!-- 充值卡 -->
            <div class="card recharge-card">
                <div class="card-icon">
                    <span class="dashicons dashicons-money-alt"></span>
                </div>
                <h2>余额充值卡</h2>
                <p>立即充值，享受消费折扣</p>
                
                <div class="card-form">
                    <button class="claim-btn <?php echo ($has_claimed && $claimed_type !== 'recharge') ? 'disabled' : ''; ?>" 
                            data-type="recharge"
                            <?php if ($has_claimed && $claimed_type !== 'recharge') echo 'disabled'; ?>>
                        <span class="btn-text">
                            <?php if ($has_claimed && $claimed_type === 'recharge') : ?>
                                已领取
                            <?php else : ?>
                                立即领取
                            <?php endif; ?>
                        </span>
                        <span class="dashicons dashicons-download"></span>
                    </button>
                    <div class="result-container">
                        <div class="success-message">卡密: <span id="recharge-code"></span></div>
                        <div class="error-message"></div>
                    </div>
                </div>
            </div>
            
            <!-- VIP卡 -->
            <div class="card vip-card">
                <div class="card-icon">
                    <span class="dashicons dashicons-awards"></span>
                </div>
                <h2>会员特权卡</h2>
                <p>开通VIP，享受专属特权</p>
                
                <div class="card-form">
                    <button class="claim-btn <?php echo ($has_claimed && $claimed_type !== 'vip') ? 'disabled' : ''; ?>" 
                            data-type="vip"
                            <?php if ($has_claimed && $claimed_type !== 'vip') echo 'disabled'; ?>>
                        <span class="btn-text">
                            <?php if ($has_claimed && $claimed_type === 'vip') : ?>
                                已领取
                            <?php else : ?>
                                立即领取
                            <?php endif; ?>
                        </span>
                        <span class="dashicons dashicons-download"></span>
                    </button>
                    <div class="result-container">
                        <div class="success-message">卡密: <span id="vip-code"></span></div>
                        <div class="error-message"></div>
                    </div>
                </div>
            </div>
        </div>
        
        <div class="countdown-container">
            <h3>领取倒计时</h3>
            <div class="countdown-timer" 
                 data-mode="<?php echo esc_attr($countdown_mode); ?>"
                 <?php if ($countdown_mode === 'hour') : ?>
                    data-hours="<?php echo esc_attr($countdown_hours); ?>"
                 <?php else : ?>
                    data-date="<?php echo esc_attr($end_date); ?>"
                    data-time="<?php echo esc_attr($end_time); ?>"
                 <?php endif; ?>>
                <div class="countdown-unit">
                    <span class="countdown-value" id="hours">00</span>
                    <span class="countdown-label">小时</span>
                </div>
                <div class="countdown-unit">
                    <span class="countdown-value" id="minutes">00</span>
                    <span class="countdown-label">分钟</span>
                </div>
                <div class="countdown-unit">
                    <span class="countdown-value" id="seconds">00</span>
                    <span class="countdown-label">秒</span>
                </div>
            </div>
            <?php if ($countdown_mode === 'date') : ?>
                <p class="countdown-date-info">活动结束时间: <span id="end-time-display"><?php echo esc_html($end_datetime); ?></span></p>
            <?php endif; ?>
        </div>
        
        <?php if (!empty($instructions_list)) : ?>
        <div class="card-notice">
            <h3>使用说明</h3>
            <ul>
                <?php foreach ($instructions_list as $instruction) : 
                    $trimmed_instruction = trim($instruction);
                    if (!empty($trimmed_instruction)) : ?>
                    <li><?php echo esc_html($trimmed_instruction); ?></li>
                <?php endif; 
                endforeach; ?>
            </ul>
        </div>
        <?php endif; ?>
    </div>
</div>

<style>
.vip-card-system-scaling {
    display: block;
    width: 100%;
    max-width: 800px;
    margin: 0 auto;
    padding: 30px;
    box-sizing: border-box;
}

.vip-card-system {
    max-width: 800px;
    margin: 0 auto;
    border-radius: 15px;
    font-family: 'Microsoft YaHei', 'Segoe UI', sans-serif;
    /* 将背景改为完全透明 */
    background: transparent !important;
    /* 同时移除阴影 */
    box-shadow: none !important;
}

/* 红色主题 */
.theme-red .card-header {
    background: linear-gradient(135deg, #dc3545, #e83e8c);
    color: white;
}

.theme-red .recharge-card {
    border-top: 4px solid #dc3545;
}

.theme-red .vip-card {
    border-top: 4px solid #e83e8c;
}

.theme-red .claim-btn {
    background: linear-gradient(to right, #dc3545, #e83e8c);
}

/* 蓝色主题 */
.theme-blue .card-header {
    background: linear-gradient(135deg, #007bff, #20c997);
    color: white;
}

.theme-blue .recharge-card {
    border-top: 4px solid #007bff;
}

.theme-blue .vip-card {
    border-top: 4px solid #20c997;
}

.theme-blue .claim-btn {
    background: linear-gradient(to right, #007bff, #20c997);
}

/* 紫色主题 */
.theme-purple .card-header {
    background: linear-gradient(135deg, #6f42c1, #d63384);
    color: white;
}

.theme-purple .recharge-card {
    border-top: 4px solid #6f42c1;
}

.theme-purple .vip-card {
    border-top: 4px solid #d63384;
}

.theme-purple .claim-btn {
    background: linear-gradient(to right, #6f42c1, #d63384);
}

/* 绿色主题 */
.theme-green .card-header {
    background: linear-gradient(135deg, #28a745, #20c997);
    color: white;
}

.theme-green .recharge-card {
    border-top: 4px solid #28a745;
}

.theme-green .vip-card {
    border-top: 4px solid #20c997;
}

.theme-green .claim-btn {
    background: linear-gradient(to right, #28a745, #20c997);
}

/* 金色主题 */
.theme-gold .card-header {
    background: linear-gradient(135deg, #ffc107, #fd7e14);
    color: white;
}

.theme-gold .recharge-card {
    border-top: 4px solid #ffc107;
}

.theme-gold .vip-card {
    border-top: 4px solid #fd7e14;
}

.theme-gold .claim-btn {
    background: linear-gradient(to right, #ffc107, #fd7e14);
}

.card-header {
    padding: 30px;
    text-align: center;
    border-radius: 15px 15px 0 0;
    margin-bottom: 30px;
}

.card-header h1 {
    font-size: 2.5rem;
    margin: 0 0 15px 0;
}

.card-header p {
    font-size: 1.2rem;
    margin: 0;
    opacity: 0.9;
}

.card-container {
    display: flex;
    gap: 30px;
    margin-bottom: 40px;
}

.card {
    flex: 1;
    padding: 25px;
    border-radius: 12px;
    background: #fff;
    box-shadow: 0 5px 15px rgba(0, 0, 0, 0.05);
    text-align: center;
    transition: transform 0.3s ease;
}

.card:hover {
    transform: translateY(-10px);
    box-shadow: 0 8px 25px rgba(0, 0, 0, 0.1);
}

.card-icon .dashicons {
    font-size: 3.5rem;
    width: auto;
    height: auto;
    margin-bottom: 20px;
}

.card h2 {
    font-size: 1.8rem;
    margin: 0 0 15px 0;
    color: #343a40;
}

.card p {
    color: #6c757d;
    margin-bottom: 25px;
    font-size: 1.1rem;
}

.card-form {
    display: flex;
    flex-direction: column;
    gap: 15px;
    align-items: center;
}

.claim-btn {
    padding: 15px 30px;
    border: none;
    border-radius: 8px;
    color: white;
    font-size: 1.1rem;
    font-weight: bold;
    cursor: pointer;
    transition: all 0.3s ease;
    display: flex;
    align-items: center;
    gap: 10px;
    width: 100%;
    justify-content: center;
}

.claim-btn:hover {
    transform: translateY(-3px);
    box-shadow: 0 5px 15px rgba(0, 0, 0, 0.2);
}

.claim-btn .dashicons {
    margin: 0;
    font-size: 1.5rem;
}

.result-container {
    width: 100%;
    margin-top: 15px;
    text-align: center;
}

.success-message {
    background: #d4edda;
    color: #155724;
    padding: 12px;
    border-radius: 8px;
    font-size: 1.1rem;
    display: none;
}

.error-message {
    background: #f8d7da;
    color: #721c24;
    padding: 12px;
    border-radius: 8px;
    font-size: 1.1rem;
    display: none;
}

.countdown-container {
    background: #f8f9fa;
    padding: 25px;
    border-radius: 12px;
    text-align: center;
    margin-bottom: 40px;
}

.countdown-container h3 {
    font-size: 1.5rem;
    margin: 0 0 25px 0;
    color: #495057;
}

.countdown-timer {
    display: flex;
    justify-content: center;
    gap: 20px;
}

.countdown-unit {
    display: flex;
    flex-direction: column;
    align-items: center;
}

.countdown-value {
    display: inline-block;
    min-width: 70px;
    padding: 15px;
    background: #fff;
    border-radius: 8px;
    font-size: 2rem;
    font-weight: bold;
    box-shadow: 0 3px 10px rgba(0, 0, 0, 0.1);
}

.countdown-label {
    margin-top: 10px;
    font-size: 1rem;
    color: #6c757d;
}

/* 新增日期模式提示 */
.countdown-date-info {
    margin-top: 15px;
    font-size: 1.1rem;
    font-weight: bold;
    color: #495057;
}

.card-notice {
    padding: 25px;
    background: #f8f9fa;
    border-radius: 12px;
}

.card-notice h3 {
    font-size: 1.5rem;
    margin: 0 0 20px 0;
    color: #495057;
    text-align: center;
}

.card-notice ul {
    list-style-type: none;
    padding: 0;
    margin: 0;
    display: grid;
    grid-template-columns: repeat(auto-fit, minmax(250px, 1fr));
    gap: 15px;
}

.card-notice li {
    background: white;
    padding: 15px;
    border-radius: 8px;
    box-shadow: 0 3px 10px rgba(0, 0, 0, 0.05);
    position: relative;
    padding-left: 40px;
}

.card-notice li:before {
    content: "•";
    position: absolute;
    left: 20px;
    top: 50%;
    transform: translateY(-50%);
    font-size: 1.5rem;
    color: #dc3545;
}

/* 新增禁用状态样式 */
.claim-btn.disabled {
    opacity: 0.6;
    cursor: not-allowed;
    background: #6c757d !important;
}

.claim-btn.disabled:hover {
    transform: none;
    box-shadow: none;
}

/* 应用充值卡背景色 */
<?php if (!empty($recharge_card_bg)): 
    $text_color = vip_card_system_get_contrast_color($recharge_card_bg);
?>
.vip-card-system .recharge-card {
    background: <?php echo esc_attr($recharge_card_bg); ?> !important;
    border: none !important;
}

.vip-card-system .recharge-card h2,
.vip-card-system .recharge-card p,
.vip-card-system .recharge-card .card-icon .dashicons {
    color: <?php echo $text_color; ?> !important;
}
<?php endif; ?>

/* 应用VIP卡背景色 */
<?php if (!empty($vip_card_bg)):
    $text_color = vip_card_system_get_contrast_color($vip_card_bg);
?>
.vip-card-system .vip-card {
    background: <?php echo esc_attr($vip_card_bg); ?> !important;
    border: none !important;
}

.vip-card-system .vip-card h2,
.vip-card-system .vip-card p,
.vip-card-system .vip-card .card-icon .dashicons {
    color: <?php echo $text_color; ?> !important;
}
<?php endif; ?>

@media (max-width: 768px) {
    .card-container {
        flex-direction: column;
    }
    
    .countdown-timer {
        flex-wrap: wrap;
    }
    
    .countdown-unit {
        flex: 1;
        min-width: 100px;
    }
}
</style>

<script>
jQuery(document).ready(function($) {
    checkActivityReset();
    initCountdown();
    
    // 新的倒计时功能 - 完全基于客户端时区
    function initCountdown() {
    const countdownElement = $('.countdown-timer');
    const countdownMode = countdownElement.data('mode');
    
    // 获取用户唯一标识（已登录用户用ID，未登录用户用IP）
    const userIdentifier = <?php echo $user_id ? "'user_" . $user_id . "'" : "'ip_" . md5($_SERVER['REMOTE_ADDR']) . "'"; ?>;
    const storageKey = `vip_card_countdown_${userIdentifier}`;
    
    let endTimestamp;
    
    // 尝试从本地存储获取保存的结束时间
    const savedTime = localStorage.getItem(storageKey);
    
    if (countdownMode === 'hour') {
        const hours = parseInt(countdownElement.data('hours'));
        
        if (savedTime) {
            // 使用保存的时间
            endTimestamp = parseInt(savedTime);
            
            // 检查是否已过期
            if (Date.now() > endTimestamp) {
                // 过期，重新设置
                endTimestamp = Date.now() + (hours * 60 * 60 * 1000);
                localStorage.setItem(storageKey, endTimestamp.toString());
            }
        } else {
            // 初次访问，创建新倒计时
            endTimestamp = Date.now() + (hours * 60 * 60 * 1000);
            localStorage.setItem(storageKey, endTimestamp.toString());
        }
    } else {
            // 日期模式：解析设置的日期和时间
            const endDate = countdownElement.data('date');
            const endTime = countdownElement.data('time');
            
            // 使用用户本地时区解析日期时间
            const [year, month, day] = endDate.split('-');
            const [hours, minutes] = endTime.split(':');
            
            // 创建Date对象（用户本地时区）
            const endDateTime = new Date(year, month - 1, day, hours, minutes, 0);
            endTimestamp = endDateTime.getTime();
            
            // 更新显示的活动结束时间（用户本地时区）
            const formattedDate = `${year}年${month}月${day}日 ${hours}:${minutes}`;
            $('#end-time-display').text(formattedDate);
        }
        
        // 更新显示函数
        function updateCountdown() {
            const now = Date.now();
            let remaining = Math.max(0, endTimestamp - now);
            
            if (remaining <= 0) {
                // 倒计时结束
                $('#hours').text('00');
                $('#minutes').text('00');
                $('#seconds').text('00');
                clearInterval(countdownInterval);
                $('.countdown-container').append('<div class="countdown-ended">活动已结束</div>');
                return;
            }
            
            // 计算时间单位
            const hours = Math.floor(remaining / (1000 * 60 * 60));
            remaining %= (1000 * 60 * 60);
            
            const minutes = Math.floor(remaining / (1000 * 60));
            remaining %= (1000 * 60);
            
            const seconds = Math.floor(remaining / 1000);
            
            // 更新显示
            $('#hours').text(hours.toString().padStart(2, '0'));
            $('#minutes').text(minutes.toString().padStart(2, '0'));
            $('#seconds').text(seconds.toString().padStart(2, '0'));
        }
        
        // 初始更新
        updateCountdown();
        
        // 设置定时器
        const countdownInterval = setInterval(updateCountdown, 1000);
        
        return countdownInterval;
    }
    
    // 初始化倒计时
    const countdownInterval = initCountdown();
    
    
    
// 在页面加载时检查活动是否重置
function checkActivityReset() {
    const lastReset = localStorage.getItem('vip_card_last_reset');
    const serverReset = <?php echo get_option('vip_card_system_last_reset', 0); ?>;
    
    if (serverReset > 0) {
        if (!lastReset || parseInt(lastReset) < serverReset) {
            // 清除所有倒计时缓存
            Object.keys(localStorage).forEach(key => {
                if (key.startsWith('vip_card_countdown_')) {
                    localStorage.removeItem(key);
                }
            });
            
            // 保存新的重置时间
            localStorage.setItem('vip_card_last_reset', serverReset);
            
            // 重新加载页面
            location.reload();
        }
    }
}


    
    
    // 卡密领取功能
    $('.claim-btn:not(.disabled)').on('click', function() {
        const cardType = $(this).data('type');
        const button = $(this);
        const resultContainer = button.siblings('.result-container');
        const successMessage = resultContainer.find('.success-message');
        const errorMessage = resultContainer.find('.error-message');
        const cardCodeSpan = cardType === 'recharge' ? $('#recharge-code') : $('#vip-code');
        
        // 重置消息状态
        successMessage.hide();
        errorMessage.hide();
        
        // 保存原始按钮内容
        const originalHtml = button.html();
        button.html('<span class="spinner"></span> 正在领取...').prop('disabled', true);
        
        // 发送AJAX请求领取卡密
        $.ajax({
            url: '<?php echo admin_url('admin-ajax.php'); ?>',
            type: 'POST',
            data: {
                action: 'vip_card_system_claim_card',
                nonce: '<?php echo wp_create_nonce('vip_card_system_nonce'); ?>',
                card_type: cardType,
                claim_timestamp: Math.floor(Date.now() / 1000)
            },
            success: function(response) {
                if (response.success) {
                    // 显示领取的卡密
                    cardCodeSpan.text(response.data.card_code);
                    successMessage.show();
                    
                    // 显示成功消息
                    successMessage.html(response.data.message);
                    
                    // 禁用当前按钮
                    button.prop('disabled', true);
                    button.addClass('disabled');
                    button.html('<span class="btn-text">已领取</span><span class="dashicons dashicons-download"></span>');
                    
                    // 禁用另一种卡类型的按钮
                    const otherType = cardType === 'recharge' ? 'vip' : 'recharge';
                    const otherButton = $(`.claim-btn[data-type="${otherType}"]`);
                    otherButton.prop('disabled', true);
                    otherButton.addClass('disabled');
                    otherButton.html('<span class="btn-text">不可领取</span><span class="dashicons dashicons-download"></span>');
                } else {
                    // 恢复按钮状态
                    button.html(originalHtml).prop('disabled', false);
                    
                    // 显示错误消息
                    errorMessage.text('错误: ' + response.data.message).show();
                }
            },
            error: function(jqXHR, textStatus, errorThrown) {
                // 恢复按钮状态
                button.html(originalHtml).prop('disabled', false);
                errorMessage.text('请求失败，请重试: ' + textStatus).show();
            }
        });
    });
    
    // 添加spinner动画
    $('<style>')
        .prop('type', 'text/css')
        .html(`
            .spinner {
                display: inline-block;
                width: 20px;
                height: 20px;
                border: 3px solid rgba(255,255,255,.3);
                border-radius: 50%;
                border-top-color: #fff;
                animation: spin 1s ease-in-out infinite;
            }
            
            @keyframes spin {
                to { transform: rotate(360deg); }
            }
            
            .countdown-ended {
                margin-top: 20px;
                padding: 10px;
                background: #f8d7da;
                color: #721c24;
                border-radius: 8px;
                font-size: 1.2rem;
                font-weight: bold;
            }
        `)
        .appendTo('head');
});
</script>