<?php
/*
Plugin Name: vip-card-system
Plugin URI: https://www.yuazw.top/vipcard/card.php
Description: Balance recharge card and VIP redemption card activity system
Version: 1.0.0
Author: maoxue698
License: GPLv2 or later
Text Domain: vip-card-system
*/

// 防止直接访问
if (!defined('ABSPATH')) {
    exit;
}

// 定义插件常量
define('VIP_CARD_SYSTEM_VERSION', '1.4.0');
define('VIP_CARD_SYSTEM_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('VIP_CARD_SYSTEM_PLUGIN_URL', plugin_dir_url(__FILE__));

// 注册激活钩子
register_activation_hook(__FILE__, 'vip_card_system_activate');
function vip_card_system_activate() {
    global $wpdb;
    
    // 设置默认选项
    add_option('vip_card_system_countdown_time', 24);
    add_option('vip_card_system_countdown_mode', 'hour'); // 默认小时模式
    add_option('vip_card_system_countdown_end_date', date('Y-m-d', strtotime('+1 day'))); // 默认明天
    add_option('vip_card_system_countdown_end_time', '23:59'); // 默认结束时间
    add_option('vip_card_system_theme', 'red');
    add_option('vip_card_system_notification_email', get_option('admin_email'));
    add_option('vip_card_system_frontend_name', 'VIP尊享卡领取中心');
    add_option('vip_card_system_welcome_message', '尊贵用户专享特权，领取您的专属VIP卡或充值卡');
    add_option('vip_card_system_usage_instructions', ''); // 使用说明默认值
    add_option('vip_card_system_page_scale', 100); // 页面缩放比例默认值
    add_option('vip_card_system_ip_restriction', 1);
    add_option('vip_card_system_time_restriction', 1);
    add_option('vip_card_system_email_notification', 1);
    
    // 添加管理员通知
    set_transient('vip_card_system_activation_notice', true, 5);
    
    // 创建或更新数据库表
    vip_card_system_create_database_table();
}

// 创建数据库表函数
function vip_card_system_create_database_table() {
    global $wpdb;
    
    $table_name = $wpdb->prefix . 'cao_cdk_tbl';
    $charset_collate = $wpdb->get_charset_collate();
    
    // 检查表是否存在
    if ($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {
        // 表不存在，创建新表
        $sql = "CREATE TABLE $table_name (
            id int(11) NOT NULL AUTO_INCREMENT,
            order_id bigint(20) unsigned NOT NULL DEFAULT '0' COMMENT '关联订单ID',
            type int(11) NOT NULL DEFAULT '1' COMMENT '1=充值卡,2=会员卡',
            amount decimal(10,2) NOT NULL DEFAULT '0.00' COMMENT '金额',
            create_time int(11) NOT NULL DEFAULT '0' COMMENT '创建时间',
            expiry_time int(11) NOT NULL DEFAULT '0' COMMENT '卡密过期时间',
            claim_time int(11) NOT NULL DEFAULT '0' COMMENT '领取时间',
            code varchar(100) NOT NULL DEFAULT '' COMMENT '卡号',
            info varchar(255) NOT NULL DEFAULT '' COMMENT 'VIP天数',
            user text NOT NULL COMMENT '用户信息(JSON格式)',
            status int(11) NOT NULL DEFAULT '0' COMMENT '0=未使用 1=已使用',
            Camilla int(11) NOT NULL DEFAULT '0' COMMENT '0=未领取 1=已领取',
            PRIMARY KEY (id),
            UNIQUE KEY code (code)
        ) $charset_collate;";
        
        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);
    } else {
        // 表已存在，检查并添加缺失字段
        $columns = $wpdb->get_results("DESCRIBE $table_name");
        $column_names = array();
        foreach ($columns as $column) {
            $column_names[] = $column->Field;
        }
        
        $alter_sql = "";
        if (!in_array('claim_time', $column_names)) {
            $alter_sql .= "ADD COLUMN claim_time int(11) NOT NULL DEFAULT '0' COMMENT '领取时间',";
        }
        if (!in_array('user', $column_names)) {
            $alter_sql .= "ADD COLUMN user text NOT NULL COMMENT '用户信息(JSON格式)',";
        }
        if (!in_array('Camilla', $column_names)) {
            $alter_sql .= "ADD COLUMN Camilla int(11) NOT NULL DEFAULT '0' COMMENT '0=未领取 1=已领取',";
        }
        
        // 移除最后一个逗号
        $alter_sql = rtrim($alter_sql, ',');
        
        if (!empty($alter_sql)) {
            $wpdb->query("ALTER TABLE $table_name $alter_sql");
        }
    }
}

// 管理通知
add_action('admin_notices', 'vip_card_system_activation_notice');
function vip_card_system_activation_notice() {
    if (get_transient('vip_card_system_activation_notice')) {
        echo '<div class="notice notice-success is-dismissible">';
        echo '<p><strong>VIP双卡系统已成功激活！</strong> 您可以在<a href="' . admin_url('admin.php?page=vip-card-system') . '">这里</a>开始配置您的VIP卡系统。</p>';
        echo '</div>';
        delete_transient('vip_card_system_activation_notice');
    }
}

// 注册管理菜单
add_action('admin_menu', 'vip_card_system_menu');
function vip_card_system_menu() {
    // 主菜单
    add_menu_page(
        'VIP双卡系统',
        'VIP双卡系统',
        'manage_options',
        'vip-card-system',
        'vip_card_system_admin_page',
        'dashicons-id-alt',
        30
    );
    
    // 添加子菜单
    add_submenu_page(
        'vip-card-system',
        '统计报表',
        '统计报表',
        'manage_options',
        'vip-card-reports',
        'vip_card_reports_page'
    );
    
    add_submenu_page(
        'vip-card-system',
        '数据库诊断',
        '数据库诊断',
        'manage_options',
        'vip-card-diagnostic',
        'vip_card_diagnostic_page'
    );
    
 
}

// 管理页面回调函数
function vip_card_system_admin_page() {
    require_once VIP_CARD_SYSTEM_PLUGIN_DIR . 'admin/admin-main.php';
}

function vip_card_reports_page() {
    require_once VIP_CARD_SYSTEM_PLUGIN_DIR . 'admin/reports.php';
}

function vip_card_diagnostic_page() {
    require_once VIP_CARD_SYSTEM_PLUGIN_DIR . 'admin/diagnostic.php';
}

// 加载脚本和样式
add_action('admin_enqueue_scripts', 'vip_card_system_admin_scripts');
function vip_card_system_admin_scripts($hook) {
    $pages = [
        'toplevel_page_vip-card-system',
        'vip-card-system_page_vip-card-reports',
        'vip-card-system_page_vip-card-diagnostic'
       
    ];
    
    if (in_array($hook, $pages)) {
        
        
        // 加载颜色选择器
        wp_enqueue_style(
            'spectrum-css',
            'https://cdnjs.cloudflare.com/ajax/libs/spectrum/1.8.1/spectrum.min.css'
        );
        
        // 加载后台脚本
        wp_enqueue_script(
            'vip-card-system-admin', 
            VIP_CARD_SYSTEM_PLUGIN_URL . 'assets/js/admin.js', 
            array('jquery'), 
            VIP_CARD_SYSTEM_VERSION,
            true
        );
        
        // 加载颜色选择器脚本
        wp_enqueue_script(
            'spectrum-js',
            'https://cdnjs.cloudflare.com/ajax/libs/spectrum/1.8.1/spectrum.min.js',
            array('jquery')
        );
        
        // 传递数据到JavaScript
        wp_localize_script('vip-card-system-admin', 'vipCardSystem', array(
            'ajaxUrl' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('vip_card_system_nonce'),
            'theme' => get_option('vip_card_system_theme', 'red'),
            'i18n' => array(
                'confirmDelete' => __('确定要删除此卡密吗？此操作不可撤销！', 'vip-card-system'),
                'processing' => __('处理中...', 'vip-card-system'),
                'error' => __('发生错误，请重试', 'vip-card-system'),
                'successAdd' => __('成功添加 %d 个卡密', 'vip-card-system'),
                'settingsSaved' => __('设置已保存', 'vip-card-system')
            )
        ));
    }
}



// 前端短代码
add_shortcode('vip_card_system', 'vip_card_system_display');
function vip_card_system_display($atts) {
    // 加载前端展示
    ob_start();
    include VIP_CARD_SYSTEM_PLUGIN_DIR . 'public/display.php';
    return ob_get_clean();
}

// 处理开启新一轮活动
add_action('wp_ajax_vip_card_system_reset_activity', 'vip_card_system_reset_activity_handler');
function vip_card_system_reset_activity_handler() {
    // 权限检查
    if (!current_user_can('manage_options')) {
        wp_send_json_error(['message' => '权限不足']);
    }
    
    // 验证nonce
    check_ajax_referer('vip_card_system_nonce', 'nonce');
    
    global $wpdb;
    $table_name = $wpdb->prefix . 'cao_cdk_tbl';
    
    // 记录当前状态
    $before_count = $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE user != ''");
    error_log("[VIP卡系统] 重置前有用户数据的记录数: $before_count");
    
    // 只重置user字段（设为空字符串）
    $result = $wpdb->query(
        "UPDATE $table_name 
         SET user = '' 
         WHERE user != ''"  // 只更新有用户信息的记录
    );
    
    // 清除所有用户的倒计时缓存
    // 1. 清除登录用户的倒计时缓存
    $user_ids = $wpdb->get_col(
        "SELECT user_id FROM {$wpdb->usermeta} WHERE meta_key = 'vip_card_countdown_end'"
    );
    
    foreach ($user_ids as $user_id) {
        delete_user_meta($user_id, 'vip_card_countdown_end');
    }
    
    // 2. 更新活动重置时间戳（用于通知前端清除缓存）
    update_option('vip_card_system_last_reset', time());
    
    if ($result === false) {
        $error = '数据库更新失败: ' . $wpdb->last_error;
        error_log('[VIP卡系统] 错误: ' . $error);
        wp_send_json_error(['message' => $error]);
    }
    
    // 记录更新结果
    $after_count = $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE user != ''");
    error_log("[VIP卡系统] 重置后有用户数据的记录数: $after_count");
    error_log("[VIP卡系统] 成功重置 $result 条记录");
    
    wp_send_json_success([
        'message' => '新一轮活动已成功开启！' . $result . '条用户记录已重置',
        'reset_count' => $result,
        'before_count' => $before_count,
        'after_count' => $after_count
    ]);
}

// 处理设置保存
add_action('wp_ajax_vip_card_system_save_settings', 'vip_card_system_save_settings_handler');
function vip_card_system_save_settings_handler() {
    // 权限检查
    if (!current_user_can('manage_options')) {
        wp_send_json_error(array('message' => '权限不足'));
    }
    
    // 验证nonce
    if (!isset($_POST['nonce']) || !wp_verify_nonce($_POST['nonce'], 'vip_card_system_nonce')) {
        wp_send_json_error(array('message' => '安全验证失败'));
    }
    
    // 解析设置数据
    if (!isset($_POST['settings'])) {
        wp_send_json_error(array('message' => '无效的设置数据'));
    }
    
    $settings = json_decode(stripslashes($_POST['settings']), true);
    
     // 保存主题设置
    if (isset($settings['theme'])) {
        update_option('vip_card_system_theme', sanitize_text_field($settings['theme']));
    }
    
    // 保存倒计时设置
    if (isset($settings['countdownMode'])) {
        update_option('vip_card_system_countdown_mode', sanitize_text_field($settings['countdownMode']));
    }
    
    if (isset($settings['countdownTime'])) {
        update_option('vip_card_system_countdown_time', absint($settings['countdownTime']));
    }
    
    // 保存日期模式设置
    if (isset($settings['countdownEndDate'])) {
        update_option('vip_card_system_countdown_end_date', sanitize_text_field($settings['countdownEndDate']));
    }
    
    if (isset($settings['countdownEndTime'])) {
        update_option('vip_card_system_countdown_end_time', sanitize_text_field($settings['countdownEndTime']));
    }
    
    // 保存通知邮箱
    if (isset($settings['adminEmail'])) {
        update_option('vip_card_system_notification_email', sanitize_email($settings['adminEmail']));
    }
    
    // 保存前台显示设置
    if (isset($settings['frontendName'])) {
        update_option('vip_card_system_frontend_name', sanitize_text_field($settings['frontendName']));
    }
    
    if (isset($settings['welcomeMessage'])) {
        update_option('vip_card_system_welcome_message', sanitize_textarea_field($settings['welcomeMessage']));
    }
    
    // 保存使用说明设置
    if (isset($settings['usageInstructions'])) {
        update_option('vip_card_system_usage_instructions', sanitize_textarea_field($settings['usageInstructions']));
    }
    
    // 保存页面缩放比例设置
    if (isset($settings['pageScale'])) {
        update_option('vip_card_system_page_scale', absint($settings['pageScale']));
    }
    
    // 保存安全设置
    if (isset($settings['ipRestriction'])) {
        update_option('vip_card_system_ip_restriction', absint($settings['ipRestriction']));
    }
    
    if (isset($settings['timeRestriction'])) {
        update_option('vip_card_system_time_restriction', absint($settings['timeRestriction']));
    }
    
    // 保存通知设置
    if (isset($settings['emailNotification'])) {
        update_option('vip_card_system_email_notification', absint($settings['emailNotification']));
    }
    
    if (isset($settings['lowStockNotification'])) {
        update_option('vip_card_system_low_stock_notification', absint($settings['lowStockNotification']));
    }
    
    // 保存用户角色设置
    if (isset($settings['userRoles'])) {
        update_option('vip_card_system_user_roles', array_map('sanitize_text_field', $settings['userRoles']));
    }
    
    // 保存卡片背景色设置
    if (isset($settings['rechargeCardBg'])) {
        update_option('vip_card_system_recharge_card_bg', sanitize_text_field($settings['rechargeCardBg']));
    }
    
    if (isset($settings['vipCardBg'])) {
        update_option('vip_card_system_vip_card_bg', sanitize_text_field($settings['vipCardBg']));
    }
    
    wp_send_json_success(array('message' => '设置已保存'));
}

// 处理卡密领取
add_action('wp_ajax_vip_card_system_claim_card', 'vip_card_system_claim_card_handler');
add_action('wp_ajax_nopriv_vip_card_system_claim_card', 'vip_card_system_claim_card_handler');
function vip_card_system_claim_card_handler() {
    // 记录请求开始
    error_log('开始处理卡密领取请求');
    
    // 验证nonce
    if (!isset($_POST['nonce']) || !wp_verify_nonce($_POST['nonce'], 'vip_card_system_nonce')) {
        $error_message = '安全验证失败: 无效的nonce';
        error_log($error_message);
        wp_send_json_error(array('message' => $error_message));
    }
    
    // 获取当前用户
    $user_id = get_current_user_id();
    if (!$user_id) {
        $error_message = '用户未登录';
        error_log($error_message);
        wp_send_json_error(array('message' => $error_message));
    }
    
    // 获取领取时间戳
    $claim_timestamp = isset($_POST['claim_timestamp']) ? intval($_POST['claim_timestamp']) : time();
    
    // 检查用户是否已经领取过卡密 - 使用user字段
    global $wpdb;
    $table_name = $wpdb->prefix . 'cao_cdk_tbl';
    
    $claimed_card = $wpdb->get_row(
        $wpdb->prepare(
            "SELECT id FROM $table_name 
             WHERE Camilla = 1 
             AND user LIKE %s
             LIMIT 1",
            '%"user_id":' . $user_id . '%'
        )
    );
    
    if ($claimed_card) {
        $error_message = '您已经领取过卡密，每位用户只能领取一种卡';
        error_log($error_message);
        wp_send_json_error(array('message' => $error_message));
    }
    
    $user = wp_get_current_user();
    $user_name = $user->display_name;
    
    // 获取卡类型
    $card_type = isset($_POST['card_type']) ? sanitize_text_field($_POST['card_type']) : '';
    if (empty($card_type)) {
        $error_message = '缺少卡类型参数';
        error_log($error_message);
        wp_send_json_error(array('message' => $error_message));
    }
    
    // 类型转换: recharge -> 1, vip -> 2
    $type_value = ($card_type === 'recharge') ? 1 : 2;
    
    // 直接从数据库获取卡密
    $card = $wpdb->get_row(
        $wpdb->prepare(
            "SELECT * FROM $table_name 
             WHERE type = %d 
             AND Camilla = 0 
             AND status = 0
             ORDER BY create_time ASC 
             LIMIT 1",
            $type_value
        )
    );
    
    if (!$card) {
        $error_message = '没有可用的卡密，类型: ' . $type_value;
        error_log($error_message);
        wp_send_json_error(array('message' => $error_message));
    }
    
    // 更新卡密状态 - 使用user字段存储JSON数据
    $update_data = array(
        'Camilla' => 1, // 标记为已领取
        'user' => json_encode(array(
            'user_id' => $user_id,
            'user_name' => $user_name
        )),
        // 添加领取时间
        'claim_time' => $claim_timestamp
    );
    
    $result = $wpdb->update(
        $table_name,
        $update_data,
        array('id' => $card->id)
    );
    
    if ($result === false) {
        $error_message = '卡密状态更新失败: ' . $wpdb->last_error;
        error_log($error_message);
        wp_send_json_error(array('message' => $error_message));
    }
    
    // 返回卡密信息给用户
    $response_data = array(
        'card_code' => $card->code,
        'message' => '卡密领取成功！请妥善保存您的卡密'
    );
    
    if ($card_type === 'recharge') {
        $response_data['message'] = '余额充值卡领取成功！卡密: ' . $card->code;
    } else {
        $response_data['message'] = '会员特权卡领取成功！卡密: ' . $card->code;
    }
    
    error_log('卡密领取成功: ' . $card->code . ' | 用户: ' . $user_name . ' | 领取时间: ' . date('Y-m-d H:i:s', $claim_timestamp));
    wp_send_json_success($response_data);
}

// 加载文本域
add_action('plugins_loaded', 'vip_card_system_load_textdomain');
function vip_card_system_load_textdomain() {
    load_plugin_textdomain('vip-card-system', false, dirname(plugin_basename(__FILE__)) . '/languages/');
}

// 数据库诊断功能
function vip_card_system_check_database() {
    global $wpdb;
    $table_name = $wpdb->prefix . 'cao_cdk_tbl';
    
    $results = array(
        'table_exists' => $wpdb->get_var("SHOW TABLES LIKE '$table_name'") == $table_name,
        'card_count' => $wpdb->get_var("SELECT COUNT(*) FROM $table_name"),
        'recharge_count' => $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE type = 1"),
        'vip_count' => $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE type = 2"),
        'available_count' => $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE Camilla = 0"),
        'claimed_count' => $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE Camilla = 1"),
        'used_count' => $wpdb->get_var("SELECT COUNT(*) FROM $table_name WHERE status = 1")
    );
    
    return $results;
}

// 添加设置链接
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'vip_card_system_add_settings_link');
function vip_card_system_add_settings_link($links) {
    $settings_link = '<a href="' . admin_url('admin.php?page=vip-card-system') . '">' . __('设置', 'vip-card-system') . '</a>';
    array_unshift($links, $settings_link);
    return $links;
}

// =====================================================================
// 新增的倒计时持久化功能
// =====================================================================

// 保存用户结束时间
add_action('wp_ajax_vip_card_save_user_time', 'vip_card_save_user_time_handler');
add_action('wp_ajax_nopriv_vip_card_save_user_time', 'vip_card_save_user_time_handler');
function vip_card_save_user_time_handler() {
    // 验证nonce
    if (!isset($_POST['nonce']) || !wp_verify_nonce($_POST['nonce'], 'vip_card_system_nonce')) {
        wp_send_json_error(['message' => '安全验证失败']);
    }
    
    $user_id = isset($_POST['user_id']) ? intval($_POST['user_id']) : 0;
    $end_time = isset($_POST['end_time']) ? intval($_POST['end_time']) : 0;
    
    if (!$user_id || !$end_time) {
        wp_send_json_error(['message' => '无效参数']);
    }
    
    // 将结束时间保存到用户meta
    update_user_meta($user_id, 'vip_card_countdown_end', $end_time);
    
    wp_send_json_success(['message' => '时间保存成功']);
}

// 获取用户保存的时间
add_action('wp_ajax_vip_card_get_saved_time', 'vip_card_get_saved_time_handler');
add_action('wp_ajax_nopriv_vip_card_get_saved_time', 'vip_card_get_saved_time_handler');
function vip_card_get_saved_time_handler() {
    // 验证nonce
    if (!isset($_POST['nonce']) || !wp_verify_nonce($_POST['nonce'], 'vip_card_system_nonce')) {
        wp_send_json_error(['message' => '安全验证失败']);
    }
    
    $user_id = isset($_POST['user_id']) ? intval($_POST['user_id']) : 0;
    
    if (!$user_id) {
        wp_send_json_error(['message' => '无效用户ID']);
    }
    
    // 从用户meta获取保存的结束时间
    $end_time = get_user_meta($user_id, 'vip_card_countdown_end', true);
    
    if ($end_time) {
        wp_send_json_success(['endTime' => $end_time]);
    } else {
        wp_send_json_success(['endTime' => 0]);
    }
}